<?php

use CodeIgniter\Router\RouteCollection;

/**
 * @var RouteCollection $routes
 */

// routes to specify open pages (public)
$routes->get('/', 'Home::index');
$routes->get('products', 'Home::index');
$routes->get('p/(:any)', 'Product::short_p/$1');
$routes->get('segera', 'Home::index');
$routes->get('contact', 'Home::index');
// other routes no need Home::index
$routes->get('login', 'Auth::index');

// custom page
$routes->get('jasaku', 'Home::index');

// routes for pages (AJAX Load)
$routes->group('page', static function ($routes) {
    $routes->get('/', 'PageLoad::index');
    $routes->get('products', 'Product::index');
    $routes->get('contact', 'PageLoad::contact');
    $routes->get('segera', 'PageLoad::asap');
    $routes->get('footer', 'PageLoad::footer');
    // custom page
    $routes->get('jasaku', 'PageLoad::c_jasaku');
});

// backend routes for products (API)
$routes->group('product', static function ($routes) {
    $routes->get('detail/(:any)', 'Product::detail/$1');
    $routes->get('variant/(:any)', 'Product::api_variant/$1');
    $routes->post('order', 'Product::order');
    $routes->get('(:any)', 'Product::short_p/$1');
});

// routes for posts news
$routes->get('news/(:any)', 'Info::index/$1');

// routes for admin login
$routes->post('login', 'Auth::login');

// routes for protected pages (All User)
$routes->group('user', ['filter' => 'isLoggedIn'], static function ($routes) {
    $routes->get('/', 'User::index');
    $routes->match(['get', 'post'], 'profile', 'User\Profile::index');
    $routes->get('logout', 'Auth::logout');
});

// routes for protected pages (Admin)
$routes->group('admin', ['filter' => 'isLoggedAdmin'], static function ($routes) {
    $routes->get('/', 'Admin::index');
    $routes->match(['get', 'post'], 'setting', 'Admin\Setting::index');
    $routes->post('setting/favicon', 'Admin\Setting::favicon');
    $routes->post('setting/favicon-delete', 'Admin\Setting::favicon_delete');
    $routes->post('setting/thumbnail', 'Admin\Setting::thumbnail');
    // routes for products (datatable)
    $routes->group('product', ['namespace' => 'App\Controllers\Admin'], static function ($routes) {
        $routes->get('/', 'ManageProduct::index');
        $routes->get('list-api', 'ManageProduct::productListApi');
        $routes->match(['get', 'post'], 'create', 'ManageProduct::create');
        $routes->match(['get', 'post'], 'sort', 'ManageProduct::sort');
        $routes->match(['get', 'post'], 'edit/(:num)', 'ManageProduct::edit/$1');
        $routes->post('delete', 'ManageProduct::delete');
        $routes->post('variant-delete', 'ManageProduct::delete_variant');
        // routes for upload image
        $routes->post('upload-image', 'ManageProduct::upload_image');
        $routes->post('delete-image', 'ManageProduct::delete_image');
    });
    // rooutes for manage user
    $routes->get('users-list-api', 'Admin\Users::userListApi');
    $routes->match(['get', 'post'], 'users', 'Admin\Users::index');
    $routes->match(['get', 'post'], 'users-add', 'Admin\AddUser::index');
    $routes->match(['get', 'post'], 'users-edit/(:any)', 'Admin\Users::edit/$1');
    $routes->post('users-delete', 'Admin\Users::delete');
    // routes for payment
    $routes->get('payment', 'Admin\Payment::index');
    $routes->get('payment/(:any)', 'Admin\Payment::api_get_payment/$1');
    $routes->delete('payment/(:any)', 'Admin\Payment::delete/$1');
    $routes->post('payment-action', 'Admin\Payment::add');
    $routes->post('payment-sort', 'Admin\Payment::sort');
    // changelog
    $routes->get('changelog', 'Admin\Changelog::index');
    // routes for posts
    $routes->group('posts', static function ($routes) {
        $routes->get('/', 'Admin\Posts::index');
        $routes->get('list-api', 'Admin\Posts::postListApi');
        $routes->match(['get', 'post'], 'create', 'Admin\Posts::create');
        $routes->match(['get', 'post'], 'edit/(:num)', 'Admin\Posts::edit/$1');
        $routes->post('delete', 'Admin\Posts::delete');
    });
});

// any routes will be redirected to Home::index
$routes->get('(:any)', static function () {
    if (session()->get('isLoggedIn')) {
        return redirect('admin');
    }
    return redirect('/');
});
