<?php

namespace App\Controllers\Admin;

use App\Controllers\BaseController;

class AddUser extends BaseController
{
    protected $userModel;

    public function __construct()
    {
        $this->userModel = new \App\Models\UserModel();
    }

    public function index()
    {
        // DB Pusher
        update_database();

        if ($this->request->getPost()) return $this->add();

        $data = [
            'title' => 'Add User'
        ];

        return view('Admin/add_user', $data);
    }

    private function add()
    {
        $form_rules = [
            'name' => [
                'label' => 'Nama Member',
                'rules' => 'required|alpha_numeric_space',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'alpha_numeric_space' => '{field} hanya boleh berisi huruf dan spasi'
                ]
            ],
            'username' => [
                'label' => 'Username',
                'rules' => 'required|alpha_numeric|is_unique[users.username]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'alpha_numeric' => '{field} hanya boleh berisi huruf dan angka',
                    'is_unique' => '{field} sudah terdaftar'
                ]
            ],
            'email' => [
                'label' => 'Email',
                'rules' => 'required|valid_email|is_unique[users.email]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'valid_email' => '{field} tidak valid',
                    'is_unique' => '{field} sudah terdaftar'
                ]
            ],
            'password' => [
                'label' => 'Password',
                'rules' => 'required|min_length[8]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 8 karakter'
                ]
            ]
        ];

        if (!$this->validate($form_rules)) {
            return redirect()->back()->withInput()->with('failed', 'periksa kembali form');
        }

        $password = (string) $this->request->getPost('password');
        $passwordHash = password_hash($password, PASSWORD_DEFAULT);
        $name = (string) $this->request->getPost('name');
        $username = (string) $this->request->getPost('username');
        $email = (string) $this->request->getPost('email');

        $data = [
            'name' => ucwords($name),
            'username' => $username,
            'email' => $email,
            'password' => $passwordHash,
            'role' => 'member',
            'is_active' => 1
        ];

        $this->userModel->insert($data);
        session()->setFlashdata('result', $data);
        session()->setFlashdata('password', $password);
        return redirect()->to('admin/add-user')->with('success', 'menambahkan user baru');
    }
}
