<?php

namespace App\Controllers\Admin;

use App\Controllers\BaseController;
use CodeIgniter\I18n\Time;

class Payment extends BaseController
{
    protected $payModel;

    public function __construct()
    {
        $this->payModel = new \App\Models\PaymentModel();
    }

    public function index()
    {
        // DB Pusher
        update_database();

        $data = [
            'title' => 'List Payment',
            'alert' => 'Tambahkan metode pembayaran yang akan digunakan oleh pelanggan.',
            'list' => $this->payModel->orderBy('sort_id', 'ASC')->findAll()
        ];
        return view('Admin/payment', $data);
    }

    public function api_get_payment($id = null)
    {
        if (!$id) return response()->setJSON([
            'status' => false,
            'message' => 'metode pembayaran tidak ditemukan',
            'data' => ''
        ]);

        $pay = $this->payModel->find($id);
        return response()->setJSON([
            'status' => true,
            'message' => 'metode pembayaran ditemukan',
            'data' => $pay
        ]);
    }

    public function add()
    {
        $id = request()->getPost('id');
        $status = 'ditambahkan';

        if ($id) {
            $pay = $this->payModel->find($id);
            $status = 'diubah';
            $newName = $pay['image'];
        }

        $form_rules = [
            'name_payment' => 'required',
            'currency' => 'required',
            'status' => 'required',
            'logo' => 'max_size[logo,1024]|is_image[logo]|mime_in[logo,image/jpg,image/jpeg,image/png,image/webp,image/svg+xml]'
        ];

        if (!$this->validate($form_rules)) {
            return redirect()->back()->withInput()->with('failed', 'Ada kesalahan');
        }

        if (request()->getFile('logo')->isValid()) {
            $logo = request()->getFile('logo');
            $newName = $logo->getRandomName();
        }

        $data = [
            'id' => $id,
            'payment_code' => $id ? $pay['payment_code'] : random_string('alnum', 10),
            'name' => request()->getPost('name_payment'),
            'currency' => request()->getPost('currency'),
            'fees_type' => request()->getPost('fees_type'),
            'fees' => request()->getPost('fees'),
            'status' => request()->getPost('status'),
            'info' => request()->getPost('info'),
            'image' => $newName,
            'updated_at' => new Time()
        ];

        $fdata['status'] = 'failed';
        $fdata['message'] = 'Metode pembayaran ' . request()->getPost('name_payment') . ' gagal ' . $status;

        $up = $this->payModel->save($data);
        if ($up) {
            if (request()->getFile('logo')->isValid()) {
                $path = 'assets/images/payment/';
                $logo->move($path, $newName);
                if ($status === 'diubah') {
                    if (file_exists($path . $pay['image'])) {
                        unlink($path . $pay['image']);
                    }
                }
            }
            $fdata['status'] = 'success';
            $fdata['message'] = 'Metode pembayaran ' . request()->getPost('name_payment') . ' ' . $status;
        }
        return redirect()->to('admin/payment')->with($fdata['status'], $fdata['message']);
    }

    public function sort()
    {
        $sort = request()->getPost('sort');

        if (!$sort) {
            return response()->setJSON([
                'status' => false,
                'message' => 'Urutan metode pembayaran tidak ditemukan',
                'data' => ''
            ]);
        }

        $i = 1;
        foreach ($sort as $id) {
            $this->payModel->update($id, ['sort_id' => $i++]);
        }

        return response()->setJSON([
            'status' => true,
            'message' => 'Urutan metode pembayaran berhasil diubah',
            'data' => ''
        ]);
    }

    public function delete($id = null)
    {
        if (!$id) {
            return response()->setJSON([
                'status' => false,
                'message' => 'Metode pembayaran tidak ditemukan',
                'data' => ''
            ]);
        }

        $pay = $this->payModel->find($id);
        $del = $this->payModel->delete($id);

        if ($del) {
            if (file_exists('assets/images/payment/' . $pay['image'])) {
                unlink('assets/images/payment/' . $pay['image']);
            }
            return response()->setJSON([
                'status' => true,
                'message' => 'Metode pembayaran berhasil dihapus',
                'data' => ''
            ]);
        }

        return response()->setJSON([
            'status' => false,
            'message' => 'Metode pembayaran gagal dihapus',
            'data' => ''
        ]);
    }
}
