<?php

namespace App\Controllers\Admin;

use App\Controllers\BaseController;

class Setting extends BaseController
{
    protected $storeModel;

    public function __construct()
    {
        $this->storeModel = new \App\Models\StoreModel();
    }

    public function index()
    {
        if (request()->getPost()) {
            return $this->save();
        }

        update_database();

        $data = [
            'title' => 'Web Setting',
            'og_themes' => og_themes(),
        ];
        return view('Admin/setting', $data);
    }

    private function save()
    {
        $form_rules = [
            'name' => [
                'label' => 'Nama toko',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'title' => [
                'label' => 'Judul toko',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'title_home' => [
                'label' => 'Judul halaman utama',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'description_home' => [
                'label' => 'Deskripsi halaman utama',
                'rules' => 'permit_empty|min_length[3]',
                'errors' => [
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'cta_home' => [
                'label' => 'Tombol halaman utama',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'tombol_beli' => [
                'label' => 'Tombol beli',
                'rules' => 'required|in_list[button,area]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'in_list' => '{field} tidak valid'
                ]
            ],
            'template_greet' => [
                'label' => 'Template sapaan',
                'rules' => 'permit_empty|min_length[3]',
                'errors' => [
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'phone' => [
                'label' => 'Nomor telepon',
                'rules' => 'required|numeric|min_length[10]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'numeric' => '{field} harus berupa angka',
                    'min_length' => '{field} minimal 10 karakter'
                ]
            ],
            'facebook' => [
                'label' => 'Facebook',
                'rules' => 'permit_empty|min_length[4]',
                'errors' => [
                    'min_length' => '{field} minimal 4 karakter'
                ]
            ],
            'instagram' => [
                'label' => 'Instagram',
                'rules' => 'permit_empty|min_length[4]',
                'errors' => [
                    'min_length' => '{field} minimal 4 karakter'
                ]
            ],
        ];

        if (!$this->validate($form_rules)) {
            // dd($this->validator->getErrors());
            return redirect()->back()->withInput()->with('failed', 'periksa kembali form');
        }

        $template_pesan = (string) request()->getPost('template_order');
        // dd(clean_p_tag($template_pesan));

        // format nomor telepon indonesia
        $phone = (string) request()->getPost('phone');
        if (substr($phone, 0, 1) == '0') {
            $phone = '62' . substr($phone, 1);
        } elseif (substr($phone, 0, 1) == '8') {
            $phone = '62' . $phone;
        } elseif (substr($phone, 0, 1) == '+') {
            $phone = substr($phone, 1);
        }

        $description = request()->getPost('description_home');

        $data = [
            'name' => request()->getPost('name'),
            'title' => request()->getPost('title'),
            'title_home' => request()->getPost('title_home'),
            'description_home' => clean_p_tag($description),
            'cta_home' => request()->getPost('cta_home'),
            'phone' => $phone,
            'facebook' => request()->getPost('facebook'),
            'instagram' => request()->getPost('instagram'),
            'template_greet' => request()->getPost('template_greet'),
            'template_order' => clean_p_tag($template_pesan),
            'btn_order_type' => request()->getPost('tombol_beli'),
        ];

        if (getStore('id')) {
            $this->storeModel->update(getStore('id'), $data);
        } else {
            $this->storeModel->insert($data);
        }

        $og_theme = getStore('og_theme') ?: 'bg_1';
        generateOgImage($og_theme);

        return redirect()->to('admin/setting')->with('success', 'memperbarui toko');
    }

    public function favicon()
    {
        $form_rules = [
            'favicon' => [
                'label' => 'Favicon',
                'rules' => 'uploaded[favicon]|max_size[favicon,1024]|is_image[favicon]|mime_in[favicon,image/png,image/jpg,image/jpeg]',
                'errors' => [
                    'uploaded' => '{field} tidak boleh kosong',
                    'max_size' => '{field} maksimal 1MB',
                    'is_image' => '{field} harus berupa gambar',
                    'mime_in' => '{field} harus berupa gambar'
                ]
            ]
        ];

        if (!$this->validate($form_rules)) {
            return redirect()->back()->withInput()->with('failed', 'periksa kembali form');
        }

        // hapus favicon lama jika ada
        if (getStore('favicon')) {
            if (file_exists('assets/images/favicon/' . getStore('favicon'))) {
                unlink('assets/images/favicon/' . getStore('favicon'));
            }
        }
        // upload favicon baru
        $favicon = request()->getFile('favicon');
        $format = $favicon->getClientExtension();
        $favicon->move('assets/images/favicon', 'favicon.' . $format, true);
        // simpan nama baru ke database
        $storeModel = new \App\Models\StoreModel();
        $storeModel->update(getStore('id'), ['favicon' => 'favicon.' . $format]);

        $og_theme = getStore('og_theme') ?: 'bg_1';
        generateOgImage($og_theme);

        return redirect()->to('admin/setting')->with('success', 'memperbarui favicon');
    }

    function favicon_delete()
    {
        // hapus favicon lama jika ada
        if (getStore('favicon')) {
            if (file_exists('assets/images/favicon/' . getStore('favicon'))) {
                unlink('assets/images/favicon/' . getStore('favicon'));
            }
        }
        // simpan nama baru ke database
        $storeModel = new \App\Models\StoreModel();
        $storeModel->update(getStore('id'), ['favicon' => null]);

        return redirect()->to('admin/setting')->with('success', 'menghapus favicon');
    }

    public function thumbnail()
    {
        $og_input = request()->getPost('og_theme');
        $og_theme = og_themes($og_input);

        // update database
        $storeModel = new \App\Models\StoreModel();
        $storeModel->update(getStore('id'), ['og_theme' => $og_theme['code']]);

        generateOgImage($og_theme['code']);
        $response = [
            'status' => 200,
            'message' => 'success',
            'theme' => $og_input,
            'data' => $og_theme
        ];

        // generate og image untuk setiap produk
        $productModel = new \App\Models\ProductModel();
        $products = $productModel->findAll();
        foreach ($products as $product) {
            generateOgImage($og_theme['code'], (array) $product);
        }

        return $this->response->setJSON($response);
    }
}
