<?php

namespace App\Controllers\Admin;

use App\Controllers\BaseController;
use CodeIgniter\I18n\Time;
use Hermawan\DataTables\DataTable;

class Users extends BaseController
{
    protected $userModel;

    public function __construct()
    {
        $this->userModel = model('UserModel');
    }

    public function index()
    {
        // DB Pusher
        update_database();

        $data = [
            'title' => 'List User'
        ];

        return view('Admin/list_user', $data);
    }

    public function userListApi()
    {
        $builder = $this->userModel->select('id, name, username, email, role, is_active, created_at');
        return DataTable::of($builder)
            ->add('action', function ($data) {
                return '<a href="' . base_url('admin/users-edit/' . $data->id) . '" class="btn btn-sm btn-warning">Edit</a>
                <button type="button" data-username="' . $data->username . '" class="btn btn-sm btn-danger userDelete">Delete</button>';
            })
            ->edit('is_active', function ($row) {
                if ($row->is_active == 1) {
                    return '<span class="badge bg-success">Aktif<span>';
                }
                return '<span class="badge bg-danger">Blokir<span>';
            })
            ->format('created_at', function ($value) {
                return date('d F Y', strtotime($value));
            })
            ->toJson();
    }

    public function delete()
    {
        $this->response->setHeader('Content-Type', 'application/json');
        if ($this->request->isAJAX()) {
            $username = $this->request->getPost('username');
            // check if user is admin, then can't delete
            $user = $this->userModel->where('username', $username)->first();
            if (!$user) return $this->response->setJSON(['status' => false, 'message' => 'User ' .  $username . ' tidak ditemukan']);
            if ($user['role'] === 'admin') {
                return $this->response->setJSON(['status' => false, 'message' => 'User admin tidak bisa dihapus']);
            }
            $this->userModel->delete($user['id']);
            return $this->response->setJSON(['status' => true, 'message' => 'User berhasil dihapus']);
        }
    }

    function edit($userId = null)
    {
        if (is_numeric($userId) === false) {
            return redirect()->to('admin/users')->withInput()->with('failed', 'user tidak ditemukan');
        }
        $user = $this->userModel->find($userId);
        if (!$user) return redirect()->to('admin/users')->withInput()->with('failed', 'User tidak ditemukan');
        if ($this->request->getPost()) return $this->edit_action();
        $data = [
            'title' => 'Edit User',
            'target' => $user
        ];
        return view('Admin/edit_user', $data);
    }

    private function edit_action()
    {
        $rules = [
            'name' => [
                'label' => 'Nama',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ],
            'username' => [
                'label' => 'Username',
                'rules' => 'required|min_length[3]|is_unique[users.username,id,' . $this->request->getPost('id') . ']',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter',
                    'is_unique' => '{field} sudah terdaftar'
                ]
            ],
            'email' => [
                'label' => 'Email',
                'rules' => 'required|valid_email|is_unique[users.email,id,' . $this->request->getPost('id') . ']',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'valid_email' => 'format {field} tidak valid',
                    'is_unique' => '{field} sudah terdaftar'
                ]
            ],
            'status' => [
                'label' => 'Status',
                'rules' => 'required',
                'errors' => [
                    'required' => '{field} tidak boleh kosong'
                ]
            ]
        ];
        if ($this->request->getPost('password') && $this->request->getPost('ubahPassword') !== '') {
            $rules['password'] = [
                'label' => 'Password',
                'rules' => 'required|min_length[3]',
                'errors' => [
                    'required' => '{field} tidak boleh kosong',
                    'min_length' => '{field} minimal 3 karakter'
                ]
            ];
        }
        if (!$this->validate($rules)) {
            return redirect()->back()->withInput()->with('failed', 'mohon periksa kembali form');
        }

        $username = $this->request->getPost('username');
        $data = [
            'name' => $this->request->getPost('name'),
            'username' => $username,
            'email' => $this->request->getPost('email'),
            'is_active' => $this->request->getPost('status'),
        ];

        $password = (string) $this->request->getPost('password');
        if ($this->request->getPost('password')) {
            $data['password'] = password_hash($password, PASSWORD_DEFAULT);
        }

        $this->userModel->update($this->request->getPost('id'), $data);
        $data['password'] = $password;
        return redirect()->back()->withInput()->with('success', $username . ' telah diupdate')->with('result', $data);
    }
}
