<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use CodeIgniter\I18n\Time;

class Auth extends BaseController
{
    public function index()
    {
        $data = [
            'title' => 'Login',
            'content' => 'login',
            'isLogin' => session()->get('isLoggedIn')
        ];
        return view('Auth/login', $data);
    }

    public function login()
    {
        $form_rules = [
            'email' => [
                'rules' => 'required|valid_email|is_not_unique[users.email]',
                'errors' => [
                    'required' => 'Email harus diisi',
                    'valid_email' => 'Email tidak valid',
                    'is_not_unique' => 'Email tidak terdaftar'
                ]
            ],
            'password' => [
                'rules' => 'required|min_length[8]',
                'errors' => [
                    'required' => 'Password harus diisi',
                    'min_length' => 'Password minimal 8 karakter'
                ]
            ]
        ];

        $validation = \Config\Services::validation();

        if (!$this->validate($form_rules)) {
            return redirect()->to('login')->withInput();
        }

        $email = $this->request->getPost('email');
        $password = (string) $this->request->getPost('password');

        $time = new Time('now', 'Asia/Jakarta', 'id_ID');
        $userModel = new \App\Models\UserModel();
        $user = $userModel->get_user(['email' => $email]);
        $password_verify = password_verify($password, $user['password']);

        if (!$password_verify) {
            $validation->setError('password', 'Password salah');
            return redirect()->to('login')->withInput();
        }

        if ($user['is_active'] == 0) {
            $validation->setError('email', 'Email belum diaktivasi');
            return redirect()->to('login')->withInput();
        }

        $data = [
            'isLoggedIn' => true,
            'time_login' => $time->addDays(7)->toDateTimeString(),
            'id' => $user['id'],
            'username' => $user['username'],
        ];

        session()->set($data);
        if ($user['role'] !== 'admin') {
            return redirect()->to('user');
        }
        return redirect()->to('admin');
    }

    public function logout()
    {
        if (!session()->get('isLoggedIn')) {
            return redirect()->to('login');
        }

        session()->destroy();
        return redirect()->to('login');
    }
}
