<?php

namespace App\Controllers;

use App\Controllers\BaseController;

class Product extends BaseController
{
    protected $pModel;
    protected $vModel;
    protected $payModel;
    protected $postModel;

    public function __construct()
    {
        $this->pModel = new \App\Models\ProductModel();
        $this->vModel = new \App\Models\VariantModel();
        $this->payModel = new \App\Models\PaymentModel();
        $this->postModel = new \App\Models\PostModel();
    }

    public function index()
    {
        $data = [
            'title' => 'Products',
            'products' => $this->pModel->getProductSorted(),
            'posts' => $this->postModel->getPosts(),
        ];
        return view('Products/index', $data);
    }

    public function detail($slug)
    {
        $product = $this->pModel->getProduct(['slug' => $slug]);
        if (!$product) {
            return redirect()->to('/product');
        }

        $data = [
            'title' => 'Product Detail',
            'product' => $product,
            'variant' => $this->vModel->getVariants(['product_id' => $product['id'], 'status' => 1]),
            'carousel_images' => product_images($product['id']),
            'payment' => $this->payModel->orderBy('sort_id', 'ASC')->findAll(),
        ];

        // dd($data);
        return view('Products/detail', $data);
    }

    public function api_variant($slug)
    {
        $variant = $this->vModel->getVariant(['slug' => $slug]);
        // dd($variant);
        if ($variant) {
            // ! new method, list the payment method then if has a fees, add to the price
            $payment = $this->payModel->orderBy('sort_id', 'ASC')->findAll();
            $paymentList = [];
            foreach ($payment as $pay) {
                // if has fees, and check fees_type is nominal or percent, then calculate total fees
                $fees = 0;
                $price = (int) $variant['price'];
                if ($pay['fees'] > 0) {
                    if ($pay['currency'] == 'IDR') {
                        if ($pay['fees_type'] == 'nominal') {
                            $fees = $pay['fees'];
                        } else if ($pay['fees_type'] == 'percent') {
                            $fees = $variant['price'] * $pay['fees'] / 100;
                        }
                    } else if ($pay['currency'] == 'USD') {
                        $price = $price / 15000;
                        if ($pay['fees_type'] == 'nominal') {
                            $fees = $pay['fees'];
                        } else if ($pay['fees_type'] == 'percent') {
                            $fees = $price * $pay['fees'] / 100;
                        }
                    }
                }

                $price_fees = ceil(($price + $fees) * 100) / 100;

                $paymentList[] = [
                    // 'id' => $pay['id'],
                    'payment_code' => $pay['payment_code'],
                    'name' => $pay['name'],
                    'currency' => $pay['currency'],
                    'logo' => $pay['image'] ? base_url('assets/img/payment/' . $pay['image']) : base_url('assets/img/payment/default.png'),
                    'status' => (bool) $pay['status'],
                    'price' => $price,
                    'fees' => $fees,
                    'total_price' => $price_fees,
                ];
            }

            $resp = [
                'status' => true,
                'message' => 'Variant found',
                'data' => $variant,
                'payment' => $paymentList,
            ];
        } else {
            $resp = [
                'status' => false,
                'message' => 'Variant not found',
                'data' => ''
            ];
        }
        return $this->response->setJSON($resp);
    }

    public function short_p($slug)
    {
        $product = $this->pModel->getProduct(['slug' => $slug]);
        if (!$product) {
            return redirect()->to('products');
        }
        return redirect()->to('products?id=' . $product['slug']);
    }

    public function order()
    {
        $postVarian = $this->request->getPost('variant');
        $postPaymen = $this->request->getPost('payment');
        $postQty = $this->request->getPost('qty');

        $form_rules = [
            'variant' => 'permit_empty',
            'payment' => 'required',
            'qty' => 'numeric',
        ];

        $validation = \Config\Services::validation();

        if (!$this->validate($form_rules)) {
            return $this->response->setJSON([
                'error' => [
                    'variant' => $validation->getError('variant'),
                    'payment' => $validation->getError('payment'),
                    'qty' => $validation->getError('qty'),
                ]
            ]);
        }

        $v_select = "product_id, slug, name, price, info, status";
        $p_select = "name, slug, price_discount, description, status, category, store_id, info, other_field, must_field";

        $varian = $this->vModel->getVariant(['slug' => $postVarian], $v_select);

        if (is_null($varian)) {
            $product = $this->pModel->getProduct(['slug' => $postVarian], $p_select);
            $varian = [
                'name' => $product['name'],
                'price' => $product['price_discount'],
                'info' => $product['info'],
                'status' => $product['status'],
            ];
        } else {
            $product = $this->pModel->getProduct(['id' => $varian['product_id']], $p_select);
        }

        // count total price with qty and fees
        $totalPrice = $varian['price'] * $postQty;

        $fees = 0;
        if ($postPaymen) {
            $payment = $this->payModel->where('payment_code', $postPaymen)->first();
            if ($payment) {
                if ($payment['fees'] > 0) {
                    if ($payment['fees_type'] == 'nominal') {
                        $fees = $payment['fees'];
                    } else if ($payment['fees_type'] == 'percent') {
                        $fees = $totalPrice * $payment['fees'] / 100;
                    }
                }
            }
        }

        // total price with fees IDR
        $totalPrice = $totalPrice + $fees;
        // total price with fees USD
        if ($payment['currency'] == 'USD') {
            $fees = $fees / 15000;
        }

        $usd_price = $totalPrice / 15000;
        $usd_price = $usd_price + $fees;
        $totalPriceUSD = ceil($usd_price * 100) / 100;

        $data_payment = [
            'name' => $payment['name'],
            'code' => $payment['payment_code'],
            'fees' => $fees,
            'total_price' => $totalPrice,
            'total_price_usd' => $totalPriceUSD,
            'is_usd' => $payment['currency'] == 'USD' ? true : false,
            'payment' => $payment,
            'info' => $payment['info'],
        ];

        $data = [
            'title' => 'Buy',
            'product' => $product,
            'variant' => $varian,
            'payment' => $data_payment,
        ];

        if (!$varian && !$product) {
            $this->response->setStatusCode(404);
            return $this->response->setJSON([
                'error' => [
                    'variant' => 'Product tidak tersedia',
                ]
            ]);
        }

        // Logic for create order

        // Logic for create payment

        // Logic for send email

        return $this->response->setJSON($data);
    }
}
