<?php

namespace App\Controllers\User;

use App\Controllers\BaseController;

class Profile extends BaseController
{
    public function index()
    {
        if (request()->getPost('oldPassword') || request()->getPost('newPassword') || request()->getPost('confirmPassword')) {
            return $this->ubah_password();
        }

        if (request()->getPost('name') || request()->getPost('email')) {
            return $this->ubah_profil();
        }

        $data = [
            'title' => 'Profil',
            'user' => getUser(),
        ];

        return view('User/profile', $data);
    }

    private function ubah_password()
    {
        $form_rules = [
            'oldPassword' => [
                'label' => 'password lama',
                'rules' => 'required|min_length[4]',
                'errors' => [
                    'required' => 'Password lama harus diisi',
                    'min_length' => 'Password lama minimal 8 karakter'
                ],
            ],
            'newPassword' => [
                'label' => 'password baru',
                'rules' => 'required|min_length[8]',
                'errors' => [
                    'required' => 'Password baru harus diisi',
                    'min_length' => 'Password baru minimal 8 karakter',
                ],
            ],
            'confirmPassword' => [
                'label' => 'konfirmasi password',
                'rules' => 'required|matches[newPassword]',
            ]
        ];

        if (!$this->validate($form_rules)) {
            return redirect()->to('user/profile')->withInput()->with('failed', 'Silahkan perbaiki form yang salah');
        }

        $userModel = new \App\Models\UserModel();
        $user = getUser();

        // check old password
        if (!password_verify((string) request()->getPost('oldPassword'), $user['password'])) {
            $this->validator->setError('oldPassword', 'Password lama salah');
            return redirect()->to('user/profile')->withInput()->with('failed', 'Password lama salah');
        }

        // update password
        $userModel->update($user['id'], [
            'password' => password_hash((string) request()->getPost('newPassword'), PASSWORD_DEFAULT),
        ]);

        return redirect()->to('user/profile')->with('success', 'Password berhasil diubah');
    }

    private function ubah_profil()
    {
        $form_rules = [
            'name' => [
                'label' => 'nama',
                'rules' => 'required|min_length[4]',
                'errors' => [
                    'required' => 'Nama harus diisi',
                    'min_length' => 'Nama minimal 4 karakter'
                ],
            ],
            'email' => [
                'label' => 'email',
                'rules' => 'required|valid_email|is_unique[users.email,id,' . getUser()['id'] . ']',
                'errors' => [
                    'required' => 'Email harus diisi',
                    'valid_email' => 'Email tidak valid',
                    'is_unique' => 'Email sudah terdaftar',
                ],
            ],
        ];

        if (!$this->validate($form_rules)) {
            return redirect()->to('user/profile')->withInput()->with('failed', 'Silahkan perbaiki form yang salah');
        }

        $userModel = new \App\Models\UserModel();
        $user = getUser();

        $remove_at = explode('@', (string) request()->getPost('email'))[0];
        // username alphanumeric
        $username = preg_replace('/[^A-Za-z0-9]/', '', $remove_at);

        // update information
        $userModel->update($user['id'], [
            'name' => (string) request()->getPost('name'),
            'username' => $username,
            'email' => (string) request()->getPost('email'),
        ]);

        // do logout if email changed
        if ($user['email'] != (string) request()->getPost('email')) {
            session()->destroy();
            return redirect()->to('login')->with('success', 'Email berhasil diubah, silahkan login kembali');
        }

        return redirect()->to('user/profile')->with('success', 'Profil berhasil diubah');
    }
}
