<?php

namespace App\Database\Migrations;

use CodeIgniter\Database\RawSql;
use CodeIgniter\Database\Migration;

class Stores extends Migration
{
    public function up()
    {
        $this->forge->addField(
            [
                'id' => [
                    'type' => 'INT',
                    'auto_increment' => true,
                ],
                'name' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                ],
                'title' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'favicon' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'title_home' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'description_home' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'cta_home' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'phone' => [
                    'type' => 'VARCHAR',
                    'constraint' => 32,
                    'null' => true,
                ],
                'facebook' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'instagram' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'template_greet' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'template_order' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'btn_order_type' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'og_theme' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'og_main' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'license_key' => [
                    'type' => 'VARCHAR',
                    'constraint' => 255,
                    'null' => true,
                ],
                'description' => [
                    'type' => 'TEXT',
                    'null' => true,
                ],
                'created_at' => [
                    'type' => 'DATETIME',
                    'null' => true,
                    'default' => new RawSql('CURRENT_TIMESTAMP'),
                ],
                'updated_at' => [
                    'type' => 'DATETIME',
                    'null' => true,
                    'default' => new RawSql('CURRENT_TIMESTAMP'),
                ]
            ]
        );
        $this->forge->addKey('id', true);
        $this->forge->createTable('stores');

        // change collation for column description, title_home, description_home, cta_home, template_greet, template_order to utf8mb4_unicode_ci
        $this->db->query('ALTER TABLE `stores` CHANGE `description` `description` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
        $this->db->query('ALTER TABLE `stores` CHANGE `title_home` `title_home` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
        $this->db->query('ALTER TABLE `stores` CHANGE `description_home` `description_home` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
        $this->db->query('ALTER TABLE `stores` CHANGE `cta_home` `cta_home` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
        $this->db->query('ALTER TABLE `stores` CHANGE `template_greet` `template_greet` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
        $this->db->query('ALTER TABLE `stores` CHANGE `template_order` `template_order` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
    }

    public function down()
    {
        $this->forge->dropTable('stores', true);
    }
}
