<?php

namespace App\Database\Migrations;

use CodeIgniter\Database\RawSql;
use CodeIgniter\Database\Migration;

class Products extends Migration
{
    public function up()
    {
        $schema = [
            'id' => [
                'type' => 'INT',
                'auto_increment' => true,
            ],
            'sort_number' => [
                'type' => 'INT',
                'constraint' => 11,
                'null' => true,
            ],
            'name' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
            ],
            'hide_price' => [
                'type' => 'TINYINT',
                'constraint' => 1,
                'default' => 0,
            ],
            'price' => [
                'type' => 'INT',
                'constraint' => 11,
                'null' => true,
            ],
            'price_discount' => [
                'type' => 'INT',
                'constraint' => 11,
                'null' => true,
            ],
            'category' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'status' => [
                'type' => 'tinyint',
                'constraint' => 1,
                'default' => 1,
            ],
            'badge' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'time_send' => [
                'type' => 'INT',
                'constraint' => 11,
                'null' => true,
            ],
            'image' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'og_image' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'image_width' => [
                'type' => 'VARCHAR',
                'constraint' => 64,
                'null' => true,
            ],
            'image_color' => [
                'type' => 'VARCHAR',
                'constraint' => 64,
                'null' => true,
            ],
            'slug' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'info' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'description' => [
                'type' => 'TEXT',
                'null' => true,
            ],
            'other_field' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'must_field' => [
                'type' => 'TINYINT',
                'constraint' => 1,
                'default' => 0,
            ],
            'type_field' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'default' => 'input'
            ],
            'default_field' => [
                'type' => 'TEXT',
                'null' => true,
            ],
            'store_id' => [
                'type' => 'INT',
                'constraint' => 11,
                'null' => true,
            ],
            'created_at' => [
                'type' => 'DATETIME',
                'null' => true,
                'default' => new RawSql('CURRENT_TIMESTAMP'),
            ],
            'updated_at' => [
                'type' => 'DATETIME',
                'null' => true,
                'default' => new RawSql('CURRENT_TIMESTAMP'),
            ],
        ];
        $this->forge->addField($schema);
        $this->forge->addKey('id', true);
        $this->forge->createTable('products', true);

        // change column description collation
        $this->db->simpleQuery('ALTER TABLE `products` CHANGE `description` `description` TEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NULL DEFAULT NULL;');
    }

    public function down()
    {
        $this->forge->dropTable('products', true);
        // delete all product images on assets/images/products, except default.png
        $files = glob('assets/images/products/*');
        foreach ($files as $file) {
            if (is_file($file) && $file != 'assets/images/products/default.png' && $file != 'assets/images/products/index.html') {
                if (file_exists($file)) {
                    unlink($file);
                }
            }
        }
        // delete all og product images on assets/images/og/products
        $files = glob('assets/images/og/products/*');
        foreach ($files as $file) {
            if (is_file($file) && $file != 'assets/images/products/index.html') {
                if (file_exists($file)) {
                    unlink($file);
                }
            }
        }
    }
}
