<?php

namespace App\Database\Migrations;

use CodeIgniter\Database\Migration;
use CodeIgniter\Database\RawSql;

class PaymentMethod extends Migration
{
    public function up()
    {
        $schema = [
            'id' => [
                'type' => 'INT',
                'auto_increment' => true,
                'unsigned' => true,
            ],
            'sort_id' => [
                'type' => 'INT',
                'unsigned' => true,
            ],
            'payment_code' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'uniqid' => true,
            ],
            'name' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
            ],
            'currency' => [
                'type' => 'ENUM',
                'constraint' => ['IDR', 'USD'],
                'default' => 'IDR',
            ],
            'fees_type' => [
                'type' => 'ENUM',
                'constraint' => ['percent', 'nominal'],
                'default' => 'nominal',
            ],
            'fees' => [
                'type' => 'INT',
                'default' => 0,
            ],
            'image' => [
                'type' => 'VARCHAR',
                'constraint' => 255,
                'null' => true,
            ],
            'status' => [
                'type' => 'tinyint',
                'constraint' => 1,
                'default' => 1,
            ],
            'info' => [
                'type' => 'TEXT',
                'null' => true,
            ],
            'created_at' => [
                'type' => 'DATETIME',
                'null' => true,
                'default' => new RawSql('CURRENT_TIMESTAMP'),
            ],
            'updated_at' => [
                'type' => 'DATETIME',
                'null' => true,
                'default' => new RawSql('CURRENT_TIMESTAMP'),
            ],
        ];

        $this->forge->addField($schema);
        $this->forge->addKey('id', true);
        $this->forge->createTable('payment_method', true);
    }

    public function down()
    {
        $this->forge->dropTable('payment_method', true);
    }
}
