<?php

function get_discount($price, $price_discount)
{
    $discount = $price - $price_discount;
    $discount = $discount / $price * 100;
    return round($discount) . "%";
}

function nomor_prefix_62($nomor)
{
    if (substr($nomor, 0, 1) == "0") {
        $nomor = "62" . substr($nomor, 1);
    } elseif (substr($nomor, 0, 1) == "8") {
        $nomor = "62" . $nomor;
    } elseif (substr($nomor, 0, 1) == "+") {
        $nomor = substr($nomor, 1);
    }
    return $nomor;
}

function getUser($param = null)
{
    $userModel = new \App\Models\UserModel();
    $user = $userModel->get_user(['username' => session()->get('username')]);
    if ($param) {
        if (is_null($user)) return null;
        return $user[$param] ?? null;
    }
    return $user;
}

function getStore($param = null)
{
    $storeModel = new \App\Models\StoreModel();
    $store = $storeModel->first();
    if ($param) {
        if (is_null($store)) return null;
        return $store[$param] ?? null;
    }
    return $store;
}

function rupiah($number)
{
    return number_to_currency($number, 'IDR', 'id_ID');
}

function generateBadge($badge, $priceDiscount = null)
{
    $bsIcon = '<i class="bi bi-asterisk"></i>';
    $bgColor = 'bg-primary';
    $text = 'Termantap';
    $show = true;

    switch ($badge) {
        case 'terlaris':
            $bsIcon = '<i class="bi bi-fire"></i>';
            $bgColor = 'bg-danger';
            $text = 'Terlaris';
            break;
        case 'fs':
            $bsIcon = '<i class="bi bi-lightning"></i>';
            $bgColor = 'bg-success';
            $text = 'Flash Sale';
            break;
        case 'diskon':
            $bsIcon = '<i class="bi bi-tag-fill"></i>';
            $bgColor = 'bg-danger';
            $text = $priceDiscount ? $priceDiscount : 'Diskon';
            break;
        case 'mantap':
            $bsIcon = '<i class="bi bi-asterisk"></i>';
            $bgColor = 'bg-primary';
            $text = 'Termantap';
            break;
        default:
            $show = false;
            break;
    }

    return $show ? '<span class="discount ' . $bgColor . '">' . $bsIcon . ' ' . $text . '</span>' : '';
}

function old_set($param = null, $data = null)
{
    if (is_null($param)) return;
    if (old($param)) {
        return old($param);
    } else {
        if ($data && isset($data[$param])) {
            return $data[$param];
        }
    }
}

function list_category()
{
    $pModel = new \App\Models\ProductModel();
    $categories = $pModel->select('category')->groupBy('category')->findAll();
    $list = [];
    // remove duplicate category
    foreach ($categories as $category) {
        $list[] = $category['category'];
    }
    return $list;
}

function list_need_field()
{
    return [
        'id_notes' => 'Catatan',
        'id_username' => 'Username',
        'id_email' => 'Email',
        'id_number' => 'Nomor',
        'id_platform' => 'ID'
    ];
}

function product_images($id = null)
{
    if (is_null($id)) return;
    $db = \Config\Database::connect();
    $builder = $db->table('product_images');
    $images = $builder->getWhere(['product_id' => $id])->getResultArray();
    // sort image by sort_number
    usort($images, function ($a, $b) {
        return $a['sort_number'] <=> $b['sort_number'];
    });
    return $images;
}

function format_pesan_wa($template_pesan = null)
{
    if (is_null($template_pesan)) return;
    // convert br tag to %0A
    $template_pesan = str_replace('<br>', '\n', $template_pesan);
    $template_pesan = str_replace('<br/>', '\n', $template_pesan);
    // convert bold tag to asterisk
    $template_pesan = str_replace('<strong>', '*', $template_pesan);
    $template_pesan = str_replace('</strong>', '*', $template_pesan);
    // remove i tag
    $template_pesan = str_replace('<i>', '_', $template_pesan);
    $template_pesan = str_replace('</i>', '_', $template_pesan);
    // remove u tag
    $template_pesan = str_replace('<u>', '~', $template_pesan);
    $template_pesan = str_replace('</u>', '~', $template_pesan);
    // remove a tag
    $template_pesan = str_replace('<a href="', '', $template_pesan);
    $template_pesan = str_replace('">', '', $template_pesan);
    $template_pesan = str_replace('</a>', '', $template_pesan);
    // remove p tag
    $template_pesan = str_replace('<p>', '', $template_pesan);
    $template_pesan = str_replace('</p>', '', $template_pesan);
    // remove div tag
    $template_pesan = str_replace('<div>', '', $template_pesan);
    $template_pesan = str_replace('</div>', '', $template_pesan);
    return $template_pesan;
}

function clean_tag($text)
{
    if (is_null($text)) return null;
    $text = str_replace('<p>', '', $text);
    $text = str_replace('</p>', '', $text);
    $text = str_replace('<br>', '', $text);
    $text = str_replace('<br/>', '', $text);
    $text = str_replace('<strong>', '', $text);
    $text = str_replace('</strong>', '', $text);
    $text = str_replace('<i>', '', $text);
    $text = str_replace('</i>', '', $text);
    $text = str_replace('<u>', '', $text);
    $text = str_replace('</u>', '', $text);
    $text = str_replace('<b>', '', $text);
    $text = str_replace('</b>', '', $text);

    return $text;
}

function clean_p_tag($text = null)
{
    if (is_null($text)) return null;
    $text = str_replace('&nbsp;', '', $text);
    $text = str_replace('</p><p>', '<br>', $text);
    $text = str_replace('<p>', '', $text);
    $text = str_replace('</p>', '', $text);
    return $text;
}

function favicon($param = null)
{
    $favicon = getStore('favicon') ?: 'favicon.png';
    $favicon_extention = getStore('favicon') ? explode('.', $favicon)[1] : 'png';
    $favicon_path = getStore('favicon') ? 'assets/images/favicon/' : 'assets/images/';
    $favicon_url = base_url($favicon_path . $favicon);

    if ($param) {
        switch ($param) {
            case 'name':
                return $favicon;
                break;
            case 'extension':
                return $favicon_extention;
                break;
            case 'path':
                return $favicon_path;
                break;
            case 'url':
                return $favicon_url;
                break;
            default:
                return $favicon_url;
                break;
        }
    }
    return $favicon_url;
}

function update_database()
{
    if (getUser('role') !== 'admin') return;
    $storeModel = new \App\Models\StoreModel();
    $productModel = new \App\Models\ProductModel();
    $paymentModel = new \App\Models\PaymentModel();

    // ? Database Update
    // ======================
    // Add favicon column
    if (!$storeModel->db->fieldExists('favicon', 'stores')) {
        $storeModel->db->query("ALTER TABLE stores ADD favicon VARCHAR(255) NULL AFTER title");
    }
    // Add btn_order_type column
    if (!$storeModel->db->fieldExists('btn_order_type', 'stores')) {
        $storeModel->db->query("ALTER TABLE stores ADD btn_order_type VARCHAR(255) NULL AFTER template_order");
        // default value button
        $storeModel->update(1, ['btn_order_type' => 'button']);
    }
    // Add og_theme column
    if (!$storeModel->db->fieldExists('og_theme', 'stores')) {
        $storeModel->db->query("ALTER TABLE stores ADD og_theme VARCHAR(255) NULL AFTER btn_order_type");
        // default value button
        $storeModel->update(1, ['og_theme' => 'bg_1']);
    }
    // add og_main column
    if (!$storeModel->db->fieldExists('og_main', 'stores')) {
        $storeModel->db->query("ALTER TABLE stores ADD og_main VARCHAR(255) NULL AFTER og_theme");
        // default value button
        $storeModel->update(1, ['og_main' => 'og_image.jpg']);
    }
    // Add other_field on products
    if (!$productModel->db->fieldExists('other_field', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD other_field VARCHAR(255) NULL AFTER description");
    }
    // Add must_field on products
    if (!$productModel->db->fieldExists('must_field', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD must_field TINYINT AFTER other_field");
    }
    // add type_field column for products
    if (!$productModel->db->fieldExists('type_field', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD type_field VARCHAR(255) NULL DEFAULT 'input' AFTER must_field");
    }
    // add default_field column for products
    if (!$productModel->db->fieldExists('default_field', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD default_field TEXT NULL AFTER type_field");
    }
    // add og_image column for products
    if (!$productModel->db->fieldExists('og_image', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD og_image VARCHAR(255) NULL AFTER image");
    }
    // add sort_number column for products
    if (!$productModel->db->fieldExists('sort_number', 'products')) {
        $productModel->db->query("ALTER TABLE products ADD sort_number INT NULL AFTER id");
    }
    // Tambahkan column info pada payment
    if (!$paymentModel->db->fieldExists('info', 'payment_method')) {
        $paymentModel->db->query("ALTER TABLE payment_method ADD info TEXT NULL AFTER status");
    }
    // ! Database Down
    // ======================
    // Remove brand column from products
    if ($productModel->db->fieldExists('brand', 'products')) {
        $productModel->db->query("ALTER TABLE products DROP brand");
    }
}

function og_themes($code = null)
{
    $list = [
        [
            'code' => 'bg_0',
            'name' => 'No Gradient (white) - Default',
            'path' => null,
            'light' => true,
        ],
        [
            'code' => 'bg_0_1',
            'name' => 'No Gradient (black)',
            'path' => null,
            'light' => false,
        ],
        [
            'code' => 'bg_1',
            'name' => 'Winter Neva',
            'path' => 'assets/images/og/bg/Winter_Neva.png',
            'light' => true,
        ],
        [
            'code' => 'bg_2',
            'name' => 'Amy Crisp',
            'path' => 'assets/images/og/bg/Amy_Crisp.png',
            'light' => false,
        ],
        [
            'code' => 'bg_3',
            'name' => 'Zeus Miracle',
            'path' => 'assets/images/og/bg/Zeus_Miracle.png',
            'light' => true,
        ],
        [
            'code' => 'bg_4',
            'name' => 'Wild Apple',
            'path' => 'assets/images/og/bg/Wild_Apple.png',
            'light' => true,
        ],
        [
            'code' => 'bg_5',
            'name' => 'Tempting Azure',
            'path' => 'assets/images/og/bg/Temp_Azure.png',
            'light' => true,
        ],
        [
            'code' => 'bg_6',
            'name' => 'Happy Fisher',
            'path' => 'assets/images/og/bg/Fisher.png',
            'light' => true,
        ],
        [
            'code' => 'bg_7',
            'name' => 'Plum Plate',
            'path' => 'assets/images/og/bg/Plum_Plate.png',
            'light' => false,
        ],
        [
            'code' => 'bg_8',
            'name' => 'Deep Blue',
            'path' => 'assets/images/og/bg/Deep_Blue.png',
            'light' => false,
        ],
    ];
    if ($code) {
        // get og theme by code
        $search = array_search($code, array_column($list, 'code'));
        if ($search) return $list[$search];
        return $list[0];
    }
    return $list;
}

function generateOgImage($og_theme = null, $product = [])
{
    // Tentukan spesifikasi og:image
    $width = 1280;
    $height = 720;

    // Membuat gambar og:image
    $image = imagecreatetruecolor($width, $height);

    // Set gambar background
    $og_theme = $og_theme ?: 'bg_0';
    $og_theme = og_themes($og_theme);

    $text_color = $og_theme['light'] ? imagecolorallocate($image, 0, 0, 0) : imagecolorallocate($image, 255, 255, 255);
    $text_sub_color = $og_theme['light'] ? imagecolorallocate($image, 50, 50, 50) : imagecolorallocate($image, 255, 255, 255);

    if ($og_theme['path']) {
        $image_gradient = imagecreatefrompng($og_theme['path']);
        imagecopyresampled($image, $image_gradient, 0, 0, 0, 0, $width, $height, imagesx($image_gradient), imagesy($image_gradient));
    } else {
        if ($og_theme['light']) {
            $background_color = imagecolorallocate($image, 255, 255, 255); // Putih
        } else {
            $background_color = imagecolorallocate($image, 0, 0, 0); // Hitam
        }
        imagefill($image, 0, 0, $background_color);
    }

    if ($product) {
        $image_path = 'assets/images/product/' . $product['image'];
    } else {
        if (getStore('favicon')) {
            $image_path = 'assets/images/favicon/' . getStore('favicon');
        } else {
            $image_path = 'assets/images/favicon.png';
        }
    }

    // get images extension
    $image_ext = explode('.', $image_path)[1];

    // Muat logo berdasar ekstensi file
    switch ($image_ext) {
        case 'png':
            $image_logo = imagecreatefrompng($image_path);
            break;
        case 'jpg':
        case 'jpeg':
            $image_logo = imagecreatefromjpeg($image_path);
            break;
        case 'webp':
            $image_logo = imagecreatefromwebp($image_path);
            break;
        default:
            $image_logo = imagecreatefrompng('assets/images/favicon.png');
            break;
    }

    list($image_logo_width, $image_logo_height) = getimagesize($image_path);

    // text item
    $text_item = $product ? $product['name'] : getStore('name');
    $font_size = 50;
    $char_height = 40;
    $font = realpath('assets/fonts/Poppins-ExtraBold.ttf');

    // Sub text (center)
    $text_sub = $product ? ucwords(getStore('name') . " - " . getStore('title')) : ucwords(getStore('title'));

    if (strlen($text_item) < 10) {
        $text_len = strlen($text_sub) * 20;
        $ini_pendek = true;
    } else {
        $text_len = strlen($text_item) * $char_height;
        $ini_pendek = false;
    }

    // buat gambar menjadi 250px / 200px jika text item kurang dari 10 karakter
    $image_logo_width = $ini_pendek ? 250 : 200;
    $image_logo_height = $image_logo_width;

    // logic for make logo + text in center
    $logo_x = ($width -= ($image_logo_width + $text_len)) / 2;
    $logo_y = $height / 2 - ($image_logo_height / 2);

    // Logo position (left)
    imagecopyresampled($image, $image_logo, $logo_x, $logo_y, 0, 0, $image_logo_width, $image_logo_height, imagesx($image_logo), imagesy($image_logo));

    // title position (right)
    $text_x = $logo_x + $image_logo_width + 30;
    $text_y = $height / 2 - ($char_height / 2) + (!$ini_pendek ? 20 : 10);

    imagettftext($image, $font_size, 0, $text_x, $text_y, $text_color, $font, $text_item);

    // Sub text (center)
    $text_sub = $product ? ucwords(getStore('name') . " - " . getStore('title')) : ucwords(getStore('title'));
    // $text_x = $logo_x + $image_logo_width + ($font_size / 2);
    $text_y = $height / 2 + ($char_height / 2) + ($font_size / 2) + (!$ini_pendek ? 10 : 0);
    $font_size = 30;
    $font = realpath('assets/fonts/Poppins-Bold.ttf');

    imagettftext($image, $font_size, 0, $text_x, $text_y, $text_sub_color, $font, $text_sub);

    // Simpan gambar og:image ke dalam path /assets/images/og/
    if ($product) {
        // $output_path = 'assets/images/og/product/' . $product['slug'] . '.jpg';
        $current_og_image = $product['og_image'];
        if ($current_og_image && $current_og_image !== 'og_image.jpg') {
            $file = 'assets/images/og/product/' . $current_og_image;
            if (file_exists($file)) unlink($file);
        }
        $slug_slice = substr($product['slug'], 0, 6);
        $output_path = 'assets/images/og/product/' . $slug_slice . uniqid() . '.jpg';
        $productModel = new \App\Models\ProductModel();
        $productModel->update($product['id'], ['og_image' => basename($output_path)]);
    } else {
        $current_og_main = getStore('og_main');
        if ($current_og_main && $current_og_main !== 'og_image.jpg') {
            $file = 'assets/images/og/' . $current_og_main;
            if (file_exists($file)) unlink($file);
        }
        $output_path = 'assets/images/og/' . uniqid() . '.jpg';
        $storeModel = new \App\Models\StoreModel();
        $storeModel->update(1, ['og_main' => basename($output_path)]);
    }

    if (!file_exists(dirname($output_path))) {
        // Buat direktori jika tidak ada
        mkdir(dirname($output_path), 0755, true);
    }

    imagejpeg($image, $output_path);
    imagedestroy($image);
}
