<?= $this->extend('Layouts/DashLayout') ?>

<?= $this->section('content') ?>

<div class="row mt-3">
    <div class="col-lg-12">
        <?= $this->include('Layouts/AlertMessage'); ?>
        <div class="card">
            <div class="card-header d-flex justify-content-between">
                <div class="fs-5">User List</div>
                <a href="<?= base_url('admin/users-add') ?>" class="btn btn-primary btn-sm">Tambah User</a>
            </div>
            <div class="card-body">
                <div class="table-responsive-xl">
                    <table class="table table-bordered" id="usersTable">
                        <thead>
                            <tr class="text-capitalize">
                                <th scope="col">#ID</th>
                                <th>name</th>
                                <th>username</th>
                                <th>email</th>
                                <th>role</th>
                                <th>status</th>
                                <th>register</th>
                                <th>action</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<?= $this->endSection() ?>

<?= $this->section('style') ?>
<?= $this->include('Layouts/DataTable') ?>
<?= $this->endSection() ?>

<?= $this->section('script') ?>
<script>
    $(document).ready(function() {
        $('#usersTable').DataTable({
            "processing": true,
            "serverSide": true,
            "ajax": "<?= base_url('admin/users-list-api') ?>",
            order: [
                [0, 'desc']
            ],
            "columnDefs": [{
                target: [0, -1],
                searchable: false,
            }],
        })
    });

    // delete user with data-username when click .userDelete
    $(document).on('click', '.userDelete', function() {
        let username = $(this).data('username');
        // sweetalert2, need type username to confirm delete this user
        Swal.fire({
            title: 'Hapus User?',
            text: "User dengan username " + username + " akan dihapus!",
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#d33',
            cancelButtonColor: '#6c757d',
            confirmButtonText: 'Hapus',
            cancelButtonText: 'Batal'
        }).then((result) => {
            if (result.isConfirmed) {
                // if user click confirm, then delete user
                $.ajax({
                    url: "<?= base_url('admin/users-delete') ?>",
                    dataType: "JSON",
                    type: "POST",
                    data: {
                        username: username
                    },
                    success: function(data) {
                        if (data.status === false) {
                            Swal.fire({
                                title: 'Gagal',
                                text: data.message,
                                icon: 'error',
                                showCancelButton: false,
                                confirmButtonText: 'OK',
                                reverseButtons: true
                            }).then((result) => {
                                $('#usersTable').DataTable().ajax.reload();
                            });
                            return;
                        }
                        Swal.fire({
                            title: 'Berhasil',
                            text: 'User telah dihapus',
                            icon: 'success',
                            showCancelButton: false,
                            confirmButtonText: 'OK',
                            reverseButtons: true
                        }).then((result) => {
                            $('#usersTable').DataTable().ajax.reload();
                        });
                    },
                    error: function(jqXHR, textStatus, errorThrown) {
                        Swal.fire({
                            title: 'Gagal',
                            text: 'User gagal dihapus',
                            icon: 'error',
                            showCancelButton: false,
                            confirmButtonText: 'OK',
                            reverseButtons: true
                        }).then((result) => {
                            $('#productTable').DataTable().ajax.reload();
                        });
                    }
                });
            }
        })
    });
</script>
<?= $this->endSection() ?>