<?= $this->extend('Layouts/DashLayout') ?>

<?= $this->section('style') ?>
<style>
    #fixedCard {
        position: sticky;
        top: 5rem;
    }
</style>
<?= $this->endSection() ?>

<?php
$width = old_set('image_width', $product);
$image_width = 100;
if ($width) {
    preg_match("/\d+/", $width, $matches);
    $extracted_width = isset($matches[0]) ? intval($matches[0]) : $image_width;
    $image_width = $extracted_width > 100 ? $image_width : $extracted_width;
}

$image = old_set('image', $product);
$image_src = $image ? base_url('assets/images/product/' . $image) : base_url('assets/images/product/default.png');

$time_send = old_set('time_send', $product);
$send = preg_match("/\d+/", $time_send, $matches) ? $matches[0] . " menit" : "instant";

$price = old_set('price', $product);
$price_discount = old_set('price_discount', $product);
?>

<?= $this->section('content') ?>

<div class="row justify-content-center mt-3">
    <div class="col-lg-3 col-md-6 mb-3">
        <div class="card card-product" data-product-status="tersedia" id="fixedCard">
            <div class="product" style="background-color: <?= old_set('image_color', $product) ?: "#fafafa" ?>;" id="previewImageColor">
                <button type="button" class="btn btn-light border product-buy <?= getStore('btn_order_type') === 'area' ? 'd-none' : 'd-block' ?>">
                    <i class="bi bi-bag-check"></i> Beli
                </button>
                <img src="<?= $product ? $image_src : base_url('assets/images/product/default.png') ?>" class="img-fluid" alt="product-logo" style="width: <?= $image_width ? $image_width . "%" : "100%" ?>;" id="previewImage">
                <span class="discount bg-danger" id="previewBadge"><i class="bi bi-fire"></i> terlaris</span>
                <div class="sent" id="previewTimeSend">proses <?= $send ?></div>
            </div>
            <div class="card-body">
                <small class="text-capitalize" id="previewCategory"><?= old_set('category', $product) ?: "kategori" ?></small>
                <h6 class="fw-semibold text-capitalize product-title" id="previewNama"><?= old_set('name', $product) ?: "nama produk" ?></h6>
                <div class="price">
                    <small style="font-size: small;"><s class="text-danger" id="previewPrice"><?= $price ? rupiah($price) : rupiah(35000) ?></s></small>
                    <br class="d-md-none">
                    <span class="fw-semibold text-primary" id="previewPriceDiscount"><?= $price_discount ? rupiah($price_discount) : rupiah(25000) ?></span>
                </div>
            </div>
            <div class="card-footer">
                <div class="d-flex justify-content-between text-uppercase fs-12">
                    <?php if ($product && !old_set('status', $product)) : ?>
                        <div class="fw-normal text-danger" id="previewStatus">
                            <i class="bi bi-x-circle-fill"></i> Habis
                        </div>
                    <?php else : ?>
                        <div class="fw-normal text-success" id="previewStatus">
                            <i class="bi bi-check-circle-fill"></i> Tersedia
                        </div>
                    <?php endif ?>
                </div>
            </div>
        </div>
        <!-- scroll ke varian -->
        <div class="d-flex justify-content-center mt-3">
            <button class="btn btn-sm btn-dark" onclick="scrollToVarian()">
                <i class="bi bi-arrow-down-circle"></i> Scroll ke Varian
            </button>
        </div>
    </div>
    <div class="col-lg-9">
        <?php if (validation_errors()) : ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <h5 class="alert-heading">Terjadi Kesalahan</h5>
                <hr>
                <?= validation_list_errors() ?>
            </div>
        <?php endif ?>
        <?= $this->include('Layouts/AlertMessage'); ?>
        <?= form_open('', ['enctype' => 'multipart/form-data']) ?>
        <div class="card mb-4">
            <div class="card-body">
                <div class="mb-3 row">
                    <label for="nama" class="col-sm-2 col-form-label">Nama</label>
                    <div class="col-sm-10">
                        <input type="text" class="form-control" id="nama" name="name" placeholder="Produk digital" value="<?= old_set('name', $product) ?>" required>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="category" class="col-sm-2 col-form-label">Kategori</label>
                    <div class="col-sm-10">
                        <input class="form-control" list="datalistOptions" id="category" name="category" placeholder="Pilih atau buat baru" value="<?= old_set('category', $product) ?>">
                        <datalist id="datalistOptions">
                            <?php foreach (list_category() as $cat) : ?>
                                <option value="<?= $cat ?>">
                                <?php endforeach ?>
                        </datalist>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="price" class="col-sm-2 col-form-label"><s>Harga Asli</s></label>
                    <div class="col-sm-10">
                        <div class="input-group">
                            <div class="input-group-text">
                                <input class="form-check-input mt-0" type="checkbox" id="hide_price" name="hide_price" value="" <?= old_set('hide_price', $product) ? 'checked' : '' ?>>
                            </div>
                            <input type="number" class="form-control" id="price" name="price" placeholder="20000" value="<?= old_set('price', $product) ?>" required>
                        </div>
                    </div>
                </div>
                <div class="alert alert-primary mt-2 py-2">
                    <i class="bi bi-info-circle"></i> Masukan harga terendah dari variant produk untuk ditampilkan pada etalase.
                </div>
                <div class="row mb-3">
                    <label for="price_discount" class="col-sm-2 col-form-label">Harga Diskon</label>
                    <div class="col-sm-10">
                        <input type="number" class="form-control" id="price_discount" name="price_discount" placeholder="10000" value="<?= old_set('price_discount', $product) ?>" required>
                    </div>
                </div>
            </div>
        </div>
        <div class="card mb-4">
            <div class="card-body">
                <div class="row mb-3">
                    <label for="time_send" class="col-sm-2 col-form-label">Waktu Proses</label>
                    <div class="col-sm-10">
                        <input class="form-control" list="dataTimeSend" id="time_send" name="time_send" placeholder="Kosongkan untuk set Instan" value="<?= old_set('time_send', $product) ?>">
                        <datalist id="dataTimeSend">
                            <option value="5 Menit">
                            <option value="30 Menit">
                            <option value="60 Menit">
                        </datalist>
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="status" class="col-sm-2 col-form-label">Status</label>
                    <?php $status_options = [
                        '1' => "Tersedia",
                        '0' => 'Habis/Tidak Tersedia'
                    ] ?>
                    <div class="col-sm-10">
                        <?= form_dropdown('status', $status_options, old_set('status', $product), 'id="status" class="form-select"') ?>
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="badge" class="col-sm-2 col-form-label">Lencana</label>
                    <?php $badge_options = [
                        'terlaris' => "Terlaris",
                        'mantap' => 'Termantap',
                        'fs' => 'Flash Sale',
                        'diskon' => 'Diskon (%)',
                        '' =>  "Tidak ada"
                    ] ?><div class="col-sm-10">
                        <?= form_dropdown('badge', $badge_options, old_set('badge', $product), 'id="badge" class="form-select"') ?>
                    </div>
                </div>
            </div>
        </div>
        <div class="card mb-4">
            <div class="card-body">
                <div class="row mb-3">
                    <label for="image" class="col-sm-2 col-form-label">Gambar</label>
                    <div class="col-sm-10">
                        <input class="form-control" type="file" id="image" name="image" value="<?= old_set('image', $product) ?>">
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="image_width" class="col-sm-2 col-form-label">Ukuran (<span id="curr_width"><?= $image_width ?: 100 ?>%</span>)</label>
                    <div class="col-sm-10">
                        <input type="range" class="form-range" min="20" max="100" step="5" id="image_width" name="image_width" value="<?= $image_width ?>">
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="image_color" class="col-sm-2 col-form-label">Warna BG</label>
                    <div class="col-sm-10">
                        <div class="d-flex">
                            <input type="color" class="form-control form-control-color w-100" id="image_color" name="image_color" value="<?= old_set('image_color', $product) ?: "#f5f5f5" ?>" title="Choose your color">
                            <button type="button" class="btn btn-danger ms-3" id="bg-reset">Reset</button>
                        </div>
                    </div>
                </div>
                <div class="col-lg-12 mb-3">
                    <label for="description" class="form-label">Deskripsi</label>
                    <textarea type="text" class="form-control" id="description" col="5" name="description" placeholder="Bergaransi 99x"><?= old_set('description', $product) ?></textarea>
                </div>
                <!-- WSIYWG -->
                <script>
                    // ckeditor set data to description
                    ClassicEditor.create(document.querySelector('#description'), {
                        toolbar: [
                            'undo', 'redo',
                            '|', 'heading',
                            '|', 'bold', 'italic',
                            '|', 'link', 'blockQuote',
                            '|', 'bulletedList', 'numberedList', 'outdent', 'indent'
                        ],
                        heading: {
                            options: [{
                                    model: 'paragraph',
                                    title: 'Paragraph',
                                    class: 'ck-heading_paragraph'
                                },
                                {
                                    model: 'heading1',
                                    view: 'h1',
                                    title: 'Heading 1',
                                    class: 'ck-heading_heading1'
                                },
                                {
                                    model: 'heading2',
                                    view: 'h2',
                                    title: 'Heading 2',
                                    class: 'ck-heading_heading2'
                                },
                                {
                                    model: 'heading3',
                                    view: 'h3',
                                    title: 'Heading 3',
                                    class: 'ck-heading_heading3'
                                }
                            ]
                        }
                    }).then(editor => {
                        editor.setData(`<?= $product ? $product['description'] : '' ?> `);
                    }).catch(error => {
                        console.error(error);
                    });
                </script>
            </div>
        </div>
        <div class="card mb-4">
            <div class="card-body">
                <div class="alert alert-info py-2">
                    <i class="bi bi-question-circle"></i> Produk memerlukan input lain? seperti ID / Username / Request tertentu. BISA!<br>
                    <strong>Tips:</strong> Berikan penjelasan untuk input pada Deskripsi untuk memudahkan calon pembeli.
                </div>
                <div class="row mb-3">
                    <label for="must_field" class="col-sm-2 col-form-label">Tipe Field</label>
                    <div class="col-sm-10">

                        <?php $field_options = [
                            'input' => 'Input (satu baris)',
                            'textarea' => "Textarea (beberapa baris)",
                        ] ?>
                        <?= form_dropdown('type_field', $field_options, old_set('type_field', $product), 'id="type_field" class="form-select"') ?>
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="other_field" class="col-sm-2 col-form-label">Nama Input</label>
                    <div class="col-sm-10">
                        <input class="form-control" list="datalistNeedField" id="other_field" name="other_field" placeholder="Kosongkan jika tidak diperlukan..." value="<?= old_set('other_field', $product) ?>">
                        <datalist id="datalistNeedField">
                            <?php foreach (list_need_field() as $nf) : ?>
                                <option value="<?= $nf ?>">
                                <?php endforeach ?>
                        </datalist>
                    </div>
                </div>
                <div class="row mb-3">
                    <label for="must_field" class="col-sm-2 col-form-label">Wajib diisi?</label>
                    <div class="col-sm-10">
                        <select class="form-select" name="must_field" id="must_field">
                            <option value="0" <?= old_set('must_field', $product) ? 'selected' : '' ?>>Tidak Harus / Opsional</option>
                            <option value="1" <?= old_set('must_field', $product) ? 'selected' : '' ?>>Harus Diisi / Diperlukan</option>
                        </select>
                    </div>
                </div>
                <!-- default field -->
                <div class="mb-3">
                    <?php $rows = isset($product['default_field']) ? substr_count($product['default_field'], "\n") + 1 : 3 ?>
                    <label for="default_field" class="form-label">Default Field (opsional) - Tipe field textarea</label>
                    <textarea type="text" class="form-control" id="default_field" rows="<?= $rows ?>" name="default_field"><?= old_set('default_field', $product) ?: 'Data diperlukan A:
Data diperlukan B:' ?></textarea>
                </div>
            </div>
        </div>
        <?= $product ? $this->include('Admin/image_product') : ''; ?>
        <div class="card mb-3">
            <div class="py-2 px-3 border-bottom d-flex justify-content-between align-items-center" id="formVarian">
                <span>
                    Variant Produk
                </span>
                <button type="button" class="btn btn-dark btn-sm addVariant">
                    <i class="bi bi-plus-circle"></i> Tambahkan
                </button>
            </div>
            <div class="card-body" id="listVariant">
                <?php $vStatus_opt = [
                    '1' => 'Tersedia',
                    '0' => 'Tidak Tersedia',
                ] ?>
                <?php if ($variant) : ?>
                    <?php $number = 1; ?>
                    <?php $variant = old('variants') ?: $variant; ?>
                    <?php foreach ($variant as $v) : ?>
                        <?php $add_number = $number++ ?>
                        <div class="col-lg-12 <?= count($variant) > 1 && $add_number < count($variant) ? "border-bottom mb-2" : "" ?>" data-row-number="<?= $add_number ?>" data-id="<?= $v['id'] ?>">
                            <label for="variant" class="form-label">Variant
                                <span class="badge bg-primary"><?= $add_number ?></span>
                                <button class="btn btn-danger btn-sm deleteVariant">DELETE</button>
                            </label>
                            <div class="row">
                                <input type="hidden" name="variants[<?= $add_number ?>][id]" value="<?= $v['id'] ?>">
                                <input type="hidden" name="variants[<?= $add_number ?>][slug]" value="<?= $v['slug'] ?>">
                                <div class="col-lg mb-3">
                                    <input type="text" class="form-control" name="variants[<?= $add_number ?>][nama]" placeholder="Nama" value="<?= old("variants[$add_number][nama]") ?: $v['name'] ?>" required>
                                </div>
                                <div class="col-lg mb-3">
                                    <input type="text" class="form-control" name="variants[<?= $add_number ?>][info]" placeholder="Info (optional)" value="<?= old("variants[$add_number][info]") ?: $v['info'] ?>">
                                </div>
                                <div class="col-lg mb-3">
                                    <input type="number" class="form-control" name="variants[<?= $add_number ?>][harga]" placeholder="Harga" value="<?= old("variants[$add_number][harga]") ?: $v['price'] ?>" required>
                                </div>
                                <div class="col-lg mb-3">
                                    <?php $vStatus = "variants[$add_number][status]" ?>
                                    <?= form_dropdown($vStatus, $vStatus_opt, old($vStatus) ?: $v['status'], 'class="form-select"') ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach ?>
                <?php else : ?>
                    <div class="col-lg-12 mb-2" data-row-number="1">
                        <label for="variant" class="form-label">Variant
                            <span class="badge bg-primary">1</span>
                            <button class="btn btn-danger btn-sm deleteVariant">DELETE</button>
                        </label>
                        <div class="row">
                            <div class="col-lg mb-3">
                                <input type="text" class="form-control newVariantName" name="variants[1][nama]" placeholder="Nama Paket" value="<?= old('variants["nama"]') ?>" required>
                            </div>
                            <div class="col-lg mb-3">
                                <input type="text" class="form-control" name="variants[1][info]" placeholder="Info (optional)" value="<?= old('variants["info"]') ?>">
                            </div>
                            <div class="col-lg mb-3">
                                <input type="number" class="form-control" name="variants[1][harga]" placeholder="Harga" value="<?= old('variants["price"]') ?>" required>
                            </div>
                            <div class="col-lg mb-3">
                                <?= form_dropdown('variants[1][status]', $vStatus_opt, old('variants[1]["status"]'), 'class="form-select"') ?>
                            </div>
                        </div>
                    </div>
                <?php endif ?>
            </div>
        </div>
        <div class="mb-3">
            <button type="submit" class="btn btn-lg btn-dark">
                <?= $product ? 'Update' : 'Tambahkan' ?> Produk
            </button>
            <?php if ($product) : ?>
                <button type="reset" class="btn btn-lg btn-danger ms-1" id="resetForm">Reset</button>
            <?php endif ?>
        </div>
        <?= form_close() ?>
    </div>
</div>

<?= $this->endSection() ?>

<?= $this->section('script') ?>
<script>
    function rupiah(number) {
        return new Intl.NumberFormat('id-ID', {
            style: 'currency',
            currency: 'IDR',
            minimumFractionDigits: 0,
            maximumFractionDigits: 0
        }).format(number);
    }

    function getDiscount(price, price_discount) {
        var discount = (price - price_discount) / price * 100;
        return Math.round(discount) + "%";
    }

    function scrollToVarian() {
        $('html, body').animate({
            scrollTop: $("#formVarian").offset().top
        }, 500);
    }

    $(document).ready(function() {
        let $previewCard = $('#fixedCard');
        let prevScrollPosition = 0;
        const fadeThreshold = 100;

        $(window).scroll(function() {
            let scrollTop = $(window).scrollTop();

            if (scrollTop > prevScrollPosition && scrollTop > fadeThreshold) {
                $previewCard.attr('style', 'top: 2rem');
            } else {
                $previewCard.attr('style', 'top: 5rem');
            }
            prevScrollPosition = scrollTop;
        });

        // dom form to card fixed (realtime preview)
        let $nama = $('#nama');
        let $hide_price = $('#hide_price');
        let $price = $('#price');
        let $price_discount = $('#price_discount');
        let $category = $('#category');

        let $status = $('#status');
        let $badge = $('#badge');
        let $time_send = $('#time_send');
        let $image = $('#image');
        let $image_color = $('#image_color');
        let $image_width = $('#image_width');

        let $previewNama = $('#previewNama');
        let $previewPrice = $('#previewPrice');
        let $previewPriceDiscount = $('#previewPriceDiscount');
        let $previewCategory = $('#previewCategory');

        let $previewBadge = $('#previewBadge');
        let $previewTimeSend = $('#previewTimeSend');
        let $previewStatus = $('#previewStatus');

        let $previewImage = $('#previewImage');
        let $previewImageColor = $('#previewImageColor');
        let $previewImageWidth = $('#previewImageWidth');

        function setBadge() {
            switch ($badge.val()) {
                case 'terlaris':
                    var bsIcon = '<i class="bi bi-fire"></i>';
                    var bgColor = 'bg-danger';
                    $previewBadge.html(bsIcon + ' Terlaris').attr('class', 'discount ' + bgColor);
                    break;
                case 'fs':
                    var bsIcon = '<i class="bi bi-lightning"></i>';
                    var bgColor = 'bg-success';
                    $previewBadge.html(bsIcon + ' Flash Sale').attr('class', 'discount ' + bgColor);
                    break;
                case 'diskon':
                    if (!$price.val() || !$price_discount.val()) {
                        alert("Harap isi harga dan harga diskon terlebih dahulu!");
                        $price.focus();
                    }
                    var bsIcon = '<i class="bi bi-tag-fill"></i>';
                    var bgColor = 'bg-danger';
                    var text = $price.val() ? getDiscount($price.val(), $price_discount.val()) : 'Diskon';
                    $previewBadge.html(bsIcon + " " + text).attr('class', 'discount ' + bgColor);
                    break;
                case 'mantap':
                    var bsIcon = '<i class="bi bi-asterisk"></i>';
                    var bgColor = 'bg-primary';
                    $previewBadge.html(bsIcon + ' Termantap').attr('class', 'discount ' + bgColor);
                    break;
                default:
                    $previewBadge.html('').attr('class', '');
                    break;
            }
        }

        setBadge();

        $nama.on('input', function() {
            $previewNama.text($nama.val() ? $nama.val() : 'Nama Produk');
            // each first word capitalilze, but if word is uppercase make word uppercase
            $nama.val($nama.val().replace(/\w\S*/g, function(txt) {
                if (txt === txt.toUpperCase()) {
                    return txt;
                } else {
                    return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
                }
            }));
        });

        $hide_price.on('input', function() {
            if ($hide_price.is(':checked')) {
                $price.attr('type', 'number');
                $previewPrice.text('');
                $hide_price.val('1');
            } else {
                $price.attr('type', 'text');
                $previewPrice.text($price.val() ? rupiah($price.val()) : rupiah(35000));
                $hide_price.val('0');
            }
        });

        // when page loaded and hide_price checked
        if ($hide_price.is(':checked')) {
            $price.attr('type', 'number');
            $previewPrice.text('');
            $hide_price.val('1');
        }

        $price.on('keyup', function() {
            if ($hide_price.is(':checked')) {
                $previewPrice.text('');
                return;
            }
            $previewPrice.text($price.val() ? rupiah($price.val()) : rupiah(35000));
        });

        $price_discount.on('keyup', function() {
            $previewPriceDiscount.text($price_discount.val() ? rupiah($price_discount.val()) : rupiah(25000));
            $('input[name="variants[1][harga]"]').val($price_discount.val());
        });

        $category.on('keyup', function() {
            $previewCategory.text($category.val() ? $category.val() : 'Kategori');
        });

        $time_send.on('input', function() {
            $previewTimeSend.text('Proses ' + ($time_send.val() ? $time_send.val() : 'Instant'));
        });

        $status.on('change', function() {
            var text = $status.val() === "1" ? 'Tersedia' : 'Habis';
            var textColor = $status.val() === "1" ? 'text-success' : 'text-danger';
            var icon = $status.val() === "1" ? '<i class="bi bi-check-circle-fill"></i>' : '<i class="bi bi-x-circle-fill"></i>';
            $previewStatus.attr('class', textColor).html(icon + ' ' + text);
        });

        $badge.on('change', function() {
            setBadge();
        });

        $image.on('change', function() {
            var file = $image[0].files[0];
            var reader = new FileReader();
            reader.onloadend = function() {
                $previewImage.attr('src', reader.result);
            }
            if (file) {
                reader.readAsDataURL(file);
            } else {
                $previewImage.attr('src', '');
            }
        });

        $image_color.on('input', function() {
            $previewImageColor.attr('style', 'background-color: ' + $image_color.val());
        });

        // $image_width slide change
        $image_width.on('input', function() {
            $previewImage.attr('style', 'width: ' + $image_width.val() + '%');
            $('#curr_width').text($image_width.val() + '%');
        });

        // button reset bg color
        $('#bg-reset').on('click', function() {
            $image_color.val('#f2f2f2');
            $previewImageColor.attr('style', 'background-color: #f2f2f2');
        });

        // ADD ROW VARIANT BUTTON
        let $addVariant = $('.addVariant');
        let $listVariant = $('#listVariant');

        $addVariant.on("click", function() {
            let $lastRow = $listVariant.find('.col-lg-12:last-child').data('row-number');
            let $newRowNumber = $lastRow + 1;
            let $newVariantForm = `
            <div class="col-lg-12 border-top pt-2" data-row-number="${$newRowNumber}">
                <label for="variant" class="form-label">Variant
                    <span class="badge bg-primary">${$newRowNumber}</span>
                    <button class="btn btn-danger btn-sm deleteVariant">DELETE</button>
                </label>
                <div class="row">
                    <div class="col-lg mb-3">
                        <input type="text" class="form-control" name="variants[${$newRowNumber}][nama]" placeholder="Nama Paket" required>
                    </div>
                    <div class="col-lg mb-3">
                        <input type="text" class="form-control" name="variants[${$newRowNumber}][info]" placeholder="Info (optional)">
                    </div>
                    <div class="col-lg mb-3">
                        <input type="number" class="form-control" name="variants[${$newRowNumber}][harga]" placeholder="Harga" required>
                    </div>
                    <div class="col-lg mb-3">
                        <select name="variants[${$newRowNumber}][status]" class="form-select">
                            <option value="1">Tersedia</option>
                            <option value="0">Tidak Tersedia</option>
                        </select>
                    </div>
                </div>
            </div>
            `;
            $listVariant.append($newVariantForm);
            reNumberRow();
            $listVariant.find('.col-lg-12:last-child input:first-child[name="variant[\'nama\']"]').focus();
        });

        function reNumberRow() {
            let $rowNumber = 1;
            $listVariant.find('.col-lg-12').each(function() {
                $(this).attr('data-row-number', $rowNumber);
                $(this).find('span').text($rowNumber);
                // all input
                $(this).find('input').each(function() {
                    let $name = $(this).attr('name');
                    let $newName = $name.replace(/variants\['\w+'\]/g, 'variants[' + $rowNumber + ']');
                    $(this).attr('name', $newName);
                });
                $rowNumber++;
            });
        }

        // DELETE ROW VARIANT BUTTON
        $listVariant.on("click", ".deleteVariant", function(e) {
            e.preventDefault();

            var $allRow = $listVariant.find('.col-lg-12').length;
            var $product_id = $(this).closest('.col-lg-12').data('id');

            if ($allRow <= 1) {
                return setNotify('Harus memiliki setidaknya 1 variant', 3000, 'bg-danger');
            }

            if ($product_id == null || $product_id == undefined) {
                $(this).closest('.col-lg-12').remove();
                reNumberRow();
                return setNotify('Berhasil menghapus variant', 3000, 'bg-success');
            }

            Swal.fire({
                title: 'Apakah kamu yakin?',
                text: "Kamu harus membuat variant baru untuk mengembalikan yang telah dihapus!",
                showCancelButton: true,
                confirmButtonText: 'Hapus',
                cancelButtonText: `Batal`,
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: window.location.origin + "/admin/product/variant-delete",
                        data: {
                            variant_id: $product_id
                        },
                        success: function(response) {
                            Swal.fire('Dihapus', '', 'success');
                            $(this).closest('.col-lg-12').remove();
                            reNumberRow();
                        },
                        error: function(response) {
                            console.log(response);
                            Swal.fire('Gagal', '', 'error');
                        }
                    });
                }
            })
        });
    });
</script>
<?= $this->endSection() ?>