<?= $this->extend('Layouts/DashLayout'); ?>

<?= $this->section('content'); ?>

<?= $this->include('Layouts/AlertMessage'); ?>
<?php if (validation_errors()) : ?>
    <div class="alert alert-warning alert-dismissible fade show" role="alert">
        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        <?= validation_list_errors() ?>
    </div>
<?php endif ?>

<div class="row justify-content-between mb-3 g-3">
    <!-- Add payment -->
    <div class="col-lg-7">
        <div class="card text-start">
            <div class="card-body">
                <?= form_open_multipart('admin/payment-action') ?>
                <?= form_hidden('id', '') ?>
                <div class="mb-3">
                    <label for="logo" class="form-label">Logo</label>
                    <input type="file" class="form-control" name="logo" id="logo" aria-describedby="help_logo">
                </div>
                <div class="mb-3">
                    <label for="name_payment" class="form-label">Nama</label>
                    <input type="text" class="form-control" name="name_payment" id="name_payment" aria-describedby="help_name" placeholder="Nama metode pembayaran, misal: Gopay" required>
                </div>
                <div class="mb-3">
                    <label for="info" class="form-label">Informasi Rekening</label>
                    <textarea class="form-control" name="info" id="info" rows="3" aria-describedby="help_description" placeholder="Nomor rekening support multi line, pisahkan dengan enter"></textarea>
                </div>
                <div class="row">
                    <div class="col-lg-6 mb-3">
                        <label for="fees_type" class="form-label">Tipe Fees</label>
                        <?= form_dropdown(

                            'fees_type',
                            [
                                '' => 'Pilih Tipe Fees',
                                'percent' => 'Percent',
                                'nominal' => 'Nominal',
                            ],
                            old('fees_type', ''),
                            [
                                'class' => 'form-select',
                                'name' => 'fees_type',
                                'id' => 'fees_type',
                                'aria-describedby' => 'help_fees_type',
                            ]
                        ) ?>
                    </div>
                    <div class="col-lg-6 mb-3">
                        <label for="fees" class="form-label">
                            Fees <small class="text-info">*Kosongkan untuk tanpa fees</small>
                        </label>
                        <input type="text" class="form-control" name="fees" id="fees" aria-describedby="help_fees" placeholder="1000 atau 2 (persen)">
                    </div>
                </div>
                <div class="row">
                    <!-- currency -->
                    <div class="col-lg-6 mb-3">
                        <label for="currency" class="form-label">Currency</label>
                        <?= form_dropdown(

                            'currency',
                            [
                                'IDR' => 'IDR',
                                'USD' => 'USD',
                            ],
                            old('currency', 'IDR'),
                            [
                                'class' => 'form-select',
                                'name' => 'currency',
                                'id' => 'currency',
                                'aria-describedby' => 'help_currency',
                                'required' => 'required'
                            ]
                        ) ?>
                    </div>
                    <!-- status -->
                    <div class="col-lg-6 mb-3">
                        <label for="status" class="form-label">Status</label>
                        <?= form_dropdown(

                            'status',
                            [
                                '1' => 'Active',
                                '0' => 'Inactive - Show',
                                '2' => 'Inactive - Hide',
                            ],
                            old('status', '1'),
                            [
                                'class' => 'form-select',
                                'name' => 'status',
                                'id' => 'status',
                                'aria-describedby' => 'help_status',
                                'required' => 'required'
                            ]
                        ) ?>
                    </div>
                </div>
                <div class="d-grid gap-2 d-md-block">
                    <button type="submit" class="btn btn-lg btn-primary">Tambah</button>
                    <button type="reset" class="btn btn-lg btn-secondary">Reset</button>
                </div>
                <?= form_close() ?>
            </div>
        </div>
    </div>
    <!-- List Payment -->
    <div class="col-lg-5">
        <div class="card">
            <div class="card-body">
                <h5 class="fw-bolder mb-2"><?= $title ?></h5>
                <?php if ($list) : ?>
                    <ul class="list-group" id="sortable">
                        <?php foreach ($list as $k => $pay) : ?>
                            <li class="list-group-item d-flex justify-content-between align-items-center sort-item" data-id="<?= $pay['id'] ?>">
                                <div class="d-flex align-items-center w-75">
                                    <i class="bi bi-list fs-4 me-2"></i>
                                    <?php if ($pay['status'] == 1) : ?>
                                        <!-- TRUE -->
                                        <i class="bi bi-check-circle-fill text-success"></i>
                                    <?php elseif ($pay['status'] == 2) : ?>
                                        <!-- FALSE 2 -->
                                        <i class="bi bi-eye-slash-fill text-dark"></i>
                                    <?php else : ?>
                                        <!-- FALSE 0 -->
                                        <i class="bi bi-circle-fill text-danger"></i>
                                    <?php endif ?>
                                    <span class="fw-medium ms-2"><?= $pay['name'] ?></span>
                                </div>
                                <img src="<?= base_url('assets/images/payment/') . $pay['image'] ?>" alt="<?= $pay['name'] ?>" class="me-3" height="25px">
                                <button type="button" class="btn btn-sm btn-outline-primary edit-payment" data-id="<?= $pay['id'] ?>">EDIT</button>
                            </li>
                        <?php endforeach ?>
                    </ul>
                    <div class="text-center">

                        <small class="text-muted">Drag & Drop list untuk mengubah urutan payment.</small>
                    </div>
                <?php else : ?>
                    <!-- FALSE -->
                    <div class="alert alert-danger" role="alert">
                        Methode pembayaran belum tersedia. Silahkan tambahkan data terlebih dahulu
                    </div>
                <?php endif ?>
            </div>
        </div>
    </div>
</div>

<?= $this->endSection(); ?>

<?= $this->section('script'); ?>
<script>
    $(document).ready(function() {
        $('#name_payment').on('input', function() {
            $(this).val($(this).val().toUpperCase());
        });
        // jika input fees di isi, maka tipe fees tidak boleh kosong
        $('#fees').on('input', function() {
            if ($(this).val()) {
                $('#fees_type').prop('required', true);
            } else {
                $('#fees_type').prop('required', false);
            }
        });
        // on click edit, ajax to get data
        $(".edit-payment").on('click', function() {
            const paymentId = $(this).data('id')
            $.ajax({
                url: `<?= current_url() ?>/${paymentId}`,
                success: function(response) {
                    if (response.status) {
                        const data = response.data;
                        setNotify(`${response.message}<br>Akan edit ${data.name}, perhatikan data saat merubah`)
                        // set data to the input DOM
                        $("input[name=id]").val(paymentId);
                        $("#name_payment").val(data.name).focus();
                        $("#currency").val(data.currency);
                        $("#fees_type").val(data.fees_type)
                        $("#fees").val(data.fees);
                        $("#status").val(data.status);
                        $("#info").val(data.info);
                        // set button tambah menjadi Simpan
                        $('button[type=submit]').text('Simpan Perubahan');
                        $('button[type=reset]').text('Batalkan').removeClass('btn-secondary').addClass('btn-danger');
                        // delete buttin if exist
                        $("#delete-payment").remove();
                        // add button delete
                        $('button[type=reset]').after(`
                            <button type="button" class="btn btn-lg btn-warning" id="delete-payment" data-id="${paymentId}">Hapus</button>
                        `);

                    } else {
                        Swal.fire(
                            'Gagal',
                            response.message,
                            'warning'
                        )
                    }
                }
            });
        });
        // click reset button
        $("button[type=reset]").on('click', function() {
            // set button Simpan menjadi Simpan
            $('input[name=id]').val('');
            $('button[type=submit]').text('Tambah');
            $('button[type=reset]').text('Reset').removeClass('btn-danger').addClass('btn-secondary');
            // delete button delete
            $("#delete-payment").remove();
        });
        // click delete button
        $(document).on('click', '#delete-payment', function() {
            const paymentId = $(this).data('id');
            Swal.fire({
                title: 'Hapus metode pembayaran?',
                text: "Apakah anda yakin ingin menghapus data ini?",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#d33',
                cancelButtonColor: '#6c757d',
                confirmButtonText: 'Hapus',
                cancelButtonText: 'Batal'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        url: `<?= current_url() ?>/${paymentId}`,
                        type: 'DELETE',
                        success: function(response) {
                            if (response.status) {
                                Swal.fire(
                                    'Terhapus',
                                    response.message,
                                    'success'
                                );
                                setTimeout(() => {
                                    window.location.reload();
                                }, 1000);
                            } else {
                                setNotify(response.message, null, 'bg-warning')
                            }
                        }
                    });
                }
            })
        });
        // function getSorted, then if sort null, re set value sort
        function getSorted() {
            const list = [];
            $(".sort-item").each(function() {
                list.push($(this).data('id'));
            });
            return list;
        }
        // sortable
        $("#sortable").sortable({
            update: function(event, ui) {
                const sort = getSorted();
                $.ajax({
                    url: `<?= base_url('admin/payment-sort') ?>`,
                    type: 'POST',
                    data: {
                        sort: sort
                    },
                    success: function(response) {
                        if (response.status) {
                            setNotify(response.message)
                        } else {
                            setNotify(response.message, null, 'bg-warning')
                        }
                    }
                });
            }
        });
    });
</script>
<?= $this->endSection(); ?>