<?= $this->extend('Layouts/DashLayout') ?>

<?= $this->section('content') ?>

<div class="row">
    <div class="col-lg-12 mb-3">
        <?php if (validation_errors()) : ?>
            <div class="alert alert-warning" role="alert">
                <?= validation_list_errors() ?>
            </div>
        <?php else : ?>
            <div class="alert alert-primary">
                Silahkan edit postingan sesuai dengan kebutuhanmu.
            </div>
        <?php endif ?>
        <div class="card">
            <div class="p-3 d-flex justify-content-between border-bottom">
                <div class="fs-5 fw-semibold">Edit Postingan | <?= $post['title'] ?></div>
            </div>
            <div class="card-body">
                <?= form_open_multipart() ?>
                <div class="mb-3">
                    <label for="title" class="form-label">Judul</label>
                    <input type="text" class="form-control" id="title" name="title" placeholder="Judul berita.." value="<?= old('title', $post['title']) ?>" required>
                    <?php if (validation_show_error('title')) : ?>
                        <div class="invalid-feedback">
                            <?= validation_show_error('title') ?>
                        </div>
                    <?php endif ?>
                </div>
                <div class="mb-3">
                    <label for="content" class="form-label">Konten</label>
                    <input type="hidden" id="content" name="content">
                    <div id="ql-content">
                        <?php if (old('content', $post['content'])) : ?>
                            <?= old('content', $post['content']) ?>
                        <?php else : ?>
                            <p>Hello World!</p>
                            <p>Some initial <strong>bold</strong> text</p>
                            <p><br /></p>
                        <?php endif ?>
                    </div>
                    <?php if (validation_show_error('content')) : ?>
                        <div class="invalid-feedback">
                            <?= validation_show_error('content') ?>
                        </div>
                    <?php endif ?>
                </div>
                <div class="mb-4 previewImage">
                    <label for="image" class="form-label">Gambar</label>
                    <input type="file" class="form-control d-none" id="image" name="image">
                    <div class="showImage mb-2">
                        <img src="<?= base_url('assets/images/post/') . old('image', $post['image']) ?>" alt="" class="img-fluid" style="max-height: 200px;">
                    </div>
                    <div>
                        <div class="btn btn-primary uploadImage">
                            <i class="bi bi-image"></i> Ganti Gambar
                        </div>
                    </div>
                    <?php if (validation_show_error('image')) : ?>
                        <div class="invalid-feedback">
                            <?= validation_show_error('image') ?>
                        </div>
                    <?php endif ?>
                </div>
                <div class="mb-3">
                    <label for="status" class="form-label">Status</label>
                    <?= form_dropdown(
                        'status',
                        [
                            '1' => 'Published',
                            '0' => 'Draft'
                        ],
                        old('status', $post['status']) ?? '1',
                        [
                            'class' => 'form-select',
                            'required' => true
                        ]
                    ) ?>
                    <?php if (validation_show_error('status')) : ?>
                        <div class="invalid-feedback">
                            <?= validation_show_error('status') ?>
                        </div>
                    <?php endif ?>
                </div>
                <div class="mb-3 text-center">
                    <button type="submit" id="simpan" class="btn btn-lg btn-dark">Perbarui</button>
                </div>
                <?= form_close() ?>
            </div>
        </div>
    </div>
</div>

<?= $this->endSection() ?>

<?= $this->section('style') ?>
<link href="https://cdn.jsdelivr.net/npm/quill@2.0.2/dist/quill.snow.css" rel="stylesheet" />
<?= $this->endSection() ?>

<?= $this->section('script') ?>
<script src="https://cdn.jsdelivr.net/npm/quill@2.0.2/dist/quill.min.js"></script>
<script>
    var quill = new Quill('#ql-content', {
        theme: 'snow'
    });

    $('.uploadImage, .showImage>img').click(function() {
        $('#image').click();
    });

    $('#image').change(function() {
        const file = $(this)[0].files[0];
        const fileReader = new FileReader();
        fileReader.onload = function() {
            $('.previewImage img').attr('src', fileReader.result);
        }
        fileReader.readAsDataURL(file);
    });

    $('#simpan').on('click', function() {
        const content = quill.root.innerHTML;
        $('#content').val(content);
    });
</script>
<?= $this->endSection() ?>