<?= $this->extend('Layouts/DashLayout') ?>

<?= $this->section('content') ?>
<div class="row mt-3">
    <div class="col-lg-12 mb-3">
        <div class="alert alert-primary">
            Sekarang kamu bisa mengubah tata letak produk dengan drag and drop. <a href="<?= base_url('admin/product/sort') ?>" class="alert-link">Klik disini</a> atau pada tombol <strong>Sortir</strong> di pojok kanan atas tabel produk.
        </div>
        <div class="card">
            <div class="p-3 d-flex justify-content-between border-bottom">
                <div class="fs-5 fw-semibold">Daftar Produk</div>
                <div>
                    <a href="<?= base_url('admin/product/create') ?>" class="btn btn-sm btn-primary">
                        <i class="bi bi-plus-circle"></i> Produk
                    </a>
                    <!-- sort button -->
                    <a href="<?= base_url('admin/product/sort') ?>" class="btn btn-sm btn-success">
                        <i class="bi bi-funnel"></i> Sortir
                    </a>
                </div>
            </div>
            <div class="card-body">
                <div class="table-responsive-xl">
                    <table class="table table-bordered" id="productTable">
                        <thead>
                            <tr class="text-capitalize">
                                <th scope="col">#ID</th>
                                <th>nama</th>
                                <th>harga asli</th>
                                <th>harga diskon</th>
                                <th>varian</th>
                                <th>kategori</th>
                                <th>status</th>
                                <th>action</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
<?= $this->endSection() ?>

<?= $this->section('style') ?>
<?= $this->include('Layouts/DataTable') ?>
<?= $this->endSection() ?>

<?= $this->section('script') ?>
<script>
    $(document).ready(function() {
        // datatable
        $('#productTable').DataTable({
            "processing": true,
            "serverSide": true,
            "ajax": "<?= base_url('admin/product/list-api') ?>",
            order: [
                [0, 'desc']
            ],
            "columnDefs": [{
                target: [0, -1],
                searchable: false,
            }],
            "columns": [{
                    "data": "product_id"
                },
                {
                    "data": "name"
                },
                {
                    "data": "price"
                },
                {
                    "data": "price_discount"
                },
                {
                    "data": "variant_count"
                },
                {
                    "data": "category"
                },
                {
                    "data": "status"
                },
                {
                    "data": "action",
                    orderable: false
                }
            ]
        });

        // deleteProduct on click
        $(document).on('click', '.product-delete', function() {
            let product_id = $(this).data('product_id');
            let product_name = $(this).parents('tr').find('td:nth-child(2)').text();
            Swal.fire({
                title: 'Apakah kamu yakin?',
                html: "Kamu harus membuat produk baru jika ingin mengembalikan <b class='text-primary'>" + product_name + "</b> yang telah dihapus",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Hapus',
                cancelButtonText: 'Batal',
                reverseButtons: true
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        url: "<?= base_url('admin/product/delete') ?>",
                        type: "POST",
                        data: {
                            product_id: product_id
                        },
                        success: function(data) {
                            Swal.fire({
                                title: 'Berhasil',
                                text: 'Produk telah dihapus',
                                icon: 'success',
                                showCancelButton: false,
                                confirmButtonText: 'OK',
                                reverseButtons: true
                            }).then((result) => {
                                $('#productTable').DataTable().ajax.reload();
                            });
                        },
                        error: function(jqXHR, textStatus, errorThrown) {
                            Swal.fire({
                                title: 'Gagal',
                                text: 'Produk gagal dihapus',
                                icon: 'error',
                                showCancelButton: false,
                                confirmButtonText: 'OK',
                                reverseButtons: true
                            }).then((result) => {
                                $('#productTable').DataTable().ajax.reload();
                            });
                        }
                    });
                }
            });
        });

    });
</script>
<?= $this->endSection() ?>