<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <?php $meta_title = (getStore('name') ?: BASE_NAME) . ($title ? " - " . $title : "") ?>

    <title><?= ucwords($meta_title) ?></title>
    <link rel="icon" href="<?= favicon() ?>" type="image/<?= favicon('extension') ?>">

    <meta name="title" content="<?= $meta_title ?>" />
    <meta name="description" content="<?= $meta_description ?>" />

    <!-- Open Graph / Facebook -->
    <meta property="og:type" content="website" />
    <meta property="og:url" content="<?= current_url() ?>" />
    <meta property="og:title" content="<?= $meta_title ?>" />
    <meta property="og:description" content="<?= $meta_description ?>" />
    <meta property="og:image" content="<?= $og_url ?>" />

    <!-- Twitter -->
    <meta property="twitter:card" content="summary_large_image" />
    <meta property="twitter:url" content="<?= current_url() ?>" />
    <meta property="twitter:title" content="<?= $meta_title ?>" />
    <meta property="twitter:description" content="<?= $meta_description ?>" />
    <meta property="twitter:image" content="<?= $og_url  ?>" />

    <!-- bootstrap -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.20/dist/sweetalert2.min.css">
    <link rel="stylesheet" href="https://unpkg.com/aos@2.3.4/dist/aos.css">
    <?= link_tag('assets/css/app.min.css') ?>

    <?= link_tag('assets/libs/owl/assets/owl.carousel.min.css') ?>

    <!-- app -->
    <script src="https://code.jquery.com/jquery-3.7.1.min.js"></script>

    <!-- custom style -->
    <?= $this->renderSection('style') ?>

</head>

<body>
    <?= $this->include('Layouts/Navbar') ?>

    <div class="container" id="app">
        <?= $this->renderSection('content') ?>
    </div>

    <div id="footer"></div>

    <?= $this->include('Layouts/Footer'); ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://unpkg.com/aos@2.3.4/dist/aos.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.20/dist/sweetalert2.all.min.js"></script>
    <?= script_tag('assets/js/app.min.js') ?>

    <?= script_tag('assets/libs/owl/owl.carousel.min.js') ?>

    <?= script_tag('assets/libs/jquery.mousewheel.js') ?>

    <script>
        let greet = "<?= getStore('template_greet') ?: 'Selamat datang!' ?>";
        $(document).ready(function() {
            const currentPath = window.location.pathname;
            const currentPage =
                currentPath || sessionStorage.getItem("currentPage") || "/";
            const pageTemp = currentPage.split(".")[0] === "index" ? "/" : currentPage;

            // remove slash on left and right
            const page = pageTemp.replace(/^\/|\/$/g, "");
            if (page === "") {
                setNotify(greet, 4000);
            }

            $(`[data-page="${page}"]`).addClass("active");

            // load page click
            $(".load-page").click(function() {
                $(".notify").remove();
                const anchor = $(this).data("page");
                console.log(anchor);
                if (sessionStorage.getItem("currentPage") !== anchor) {
                    loadPage(anchor == "/" || anchor == "#" ? "/" : anchor);
                } else {
                    if (anchor === "products" && sessionStorage.getItem("currentProduct")) {
                        sessionStorage.removeItem("currentProduct");
                        loadPage("products");
                    }
                }
            });

            // check if pageUrl have slash more than 1 (not valid url)
            if (page.split("/").length > 2) {
                pageUrl = page.split("/")[1];
                return window.location.href = "/";
            }

            loadPage(page);
            applyLazyLoading();
        });
    </script>

    <!-- Custom Script -->
    <?= $this->renderSection('script') ?>
</body>

</html>