const loadingMessage = `<div class='super-center'>Tunggu sebentar...</div>`;
// capitalize each word
function capitalize(string) {
  return string
    .split(" ")
    .map((word) => word[0].toUpperCase() + word.substring(1))
    .join(" ");
}

// get parameter from url
function getParams(name) {
  const url = window.location.href;
  name = name.replace(/[\[\]]/g, "\\$&");
  const regex = new RegExp("[?&]" + name + "(=([^&#]*)|&|#|$)");
  const results = regex.exec(url);
  if (!results) return null;
  if (!results[2]) return "";
  return decodeURIComponent(results[2].replace(/\+/g, " "));
}

// set notify
function setNotify(message, time = 2000, setClass = "bg-primary") {
  $(".notify").remove();
  const random = Math.random().toString(36).substr(2, 9);
  $("body").append(
    `<div class='notify ${random} ${setClass}'>${message}</div>`
  );
  setTimeout(() => {
    $(`.${random}`)
      .addClass("fade-out")
      .delay(500)
      .queue(function () {
        $(this).remove().dequeue();
      });
  }, time);
}

// Fungsi untuk mengubah warna elemen jika terang
function ubahWarnaJikaTerang($elemen) {
  // Ambil warna latar belakang elemen dalam format RGB
  var warnaRGB = $elemen.css("background-color");

  // Ubah format RGB menjadi nilai numerik
  var warnaNumerik = warnaRGB.match(/\d+/g);

  // Hitung kecerahan elemen (rata-rata nilai RGB)
  var kecerahan =
    (parseInt(warnaNumerik[0]) +
      parseInt(warnaNumerik[1]) +
      parseInt(warnaNumerik[2])) /
    3;

  // Tentukan batas kecerahan yang dianggap terang (contoh: 200)
  var batasKecerahan = 200;

  // Jika elemen terang, ubah warna
  if (kecerahan > batasKecerahan) {
    $elemen.css("background-color", "#1c1c1c"); // Ganti dengan warna yang diinginkan
  }
}

// load page
function loadPage(pageUrl, updateHistory = true) {
  $(".navbar-collapse").collapse("hide");
  $("#LayoutFooter").hide();
  $(".nav-link").removeClass("active");
  $.ajax({
    url: `page/${pageUrl}`,
    type: "GET",
    dataType: "html",
    beforeSend: function () {
      $("#app").html(loadingMessage);
    },
    success: function (response) {
      $("#app").html(response).hide().fadeIn(300);
      applyLazyLoading();
      $("#LayoutFooter").show();
      if (updateHistory) {
        $(`[data-page="${pageUrl}"]`).addClass("active");
        history.pushState({ page: pageUrl }, null, pageUrl);
      }
      // if html has data-bs-theme attribute and value is dark, change each button if has class btn-dark to btn-light
      if ($("html").attr("data-bs-theme")) {
        if ($("html").attr("data-bs-theme") === "dark") {
          $(".btn-dark").addClass("btn-light").removeClass("btn-dark");
          $(".product").each(function () {
            ubahWarnaJikaTerang($(this));
          });
        }
      }
      sessionStorage.setItem("currentPage", pageUrl);
    },
    error: function (xhr, status, error) {
      var msg_404 = "Halaman tidak ditemukan";
      var msg = xhr.status == 404 ? msg_404 : `${error}`;
      setNotify(msg, 4000);
      $("#app").html(
        `<div class='super-center flex-column'>
          <h1>${xhr.status}</h1><strong>/${pageUrl}</strong> ${msg}
        </div>`
      );
    },
  });
}

// lazy loading
function applyLazyLoading() {
  const lazyImages = $(".lazy-load-image");
  const lazyImageOptions = {
    threshold: 0.5,
  };

  const lazyImageObserver = new IntersectionObserver(function (entries) {
    entries.forEach(function (entry) {
      if (entry.isIntersecting) {
        const lazyImage = $(entry.target);
        const dataSrc = lazyImage.attr("data-src");
        lazyImage.attr("src", dataSrc);
        dataSrc && lazyImage.removeAttr("data-src");
        lazyImage.removeClass("lazy-load-image");
        lazyImageObserver.unobserve(entry.target);
      }
    });
  }, lazyImageOptions);

  lazyImages.each(function () {
    lazyImageObserver.observe(this);
  });
}

function applyCustomCSS(page) {
  // domain name
  const domainName = window.location.origin;
  if (page === "products") {
    // Add CSS to body
    // ? Set background image
    var imgBG = `url('${domainName}/assets/images/bg/products.webp')`;
    document.body.style.backgroundImage = imgBG;
    document.body.style.backgroundPosition = "center";
    document.body.style.backgroundSize = "cover";
    document.body.style.backgroundAttachment = "fixed";
    // ? Set background color (optional)
    // document.body.style.background = "#34373c";
    // - set color text
    document.body.style.color = "white";
    // Add CSS to card and modal-title
    document.querySelectorAll(".card, .modal-title").forEach(function (el) {
      el.style.color = "black";
    });
    // custom footer
    fetch(`${domainName}/page/footer`)
      .then((response) => response.text())
      .then((data) => {
        var footer = document.getElementById("footer");
        footer.innerHTML = data;
      });
  } else {
    // ? Reset CSS to default
    document.body.style.backgroundImage = "none";
    document.body.style.backgroundPosition = "unset";
    document.body.style.backgroundSize = "unset";
    document.body.style.backgroundAttachment = "unset";
    // ? Set background color (optional)
    // document.body.style.background = "unset";
    // - set color text
    document.body.style.color = "black";
    // Add CSS to card and modal-title
    document.querySelectorAll(".card, .modal-title").forEach(function (el) {
      el.style.color = "white";
    });
    document.getElementById("LayoutFooter") &&
      document.getElementById("LayoutFooter").remove();
  }
}

// document ready
$(document).ready(function () {
  let prevScrollPosition = 0;
  const fadeThreshold = 100;

  // scroll
  $(window).scroll(function () {
    const currentScrollPosition = $(window).scrollTop();
    const isScrollingDown =
      currentScrollPosition > prevScrollPosition &&
      currentScrollPosition > fadeThreshold;
    $("#topNav").toggleClass("fade-out", isScrollingDown);
    $("#topNav").toggleClass("fixed-top fade-in", !isScrollingDown);
    prevScrollPosition = currentScrollPosition;
  });

  // popstate
  $(window).on("popstate", function (e) {
    const pageUrl = e.originalEvent.state ? e.originalEvent.state.page : "/";
    loadPage(pageUrl, false);
  });

  if (getParams("id")) {
    sessionStorage.setItem("currentProduct", getParams("id"));
  }

  if (sessionStorage.getItem("bannerAlert") !== "closed") {
    $("#bannerAlert").removeClass("d-none").fadeIn(300);
  }

  $(".closeBannerAlert").on("click", function () {
    sessionStorage.setItem("bannerAlert", "closed");
    $("#bannerAlert").fadeOut(300);
  });

  applyLazyLoading();
});
