/*!
 * Color mode toggler for Bootstrap's docs (https://getbootstrap.com/)
 * Copyright 2011-2023 The Bootstrap Authors
 * Licensed under the Creative Commons Attribution 3.0 Unported License.
 */

(() => {
  "use strict";

  const getStoredTheme = () => localStorage.getItem("theme");
  const setStoredTheme = (theme) => localStorage.setItem("theme", theme);

  const getPreferredTheme = () => {
    const storedTheme = getStoredTheme();
    if (storedTheme) {
      return storedTheme;
    }

    return window.matchMedia("(prefers-color-scheme: dark)").matches
      ? "dark"
      : "light";
  };

  const ubahWarnaJikaTerang = ($elemen) => {
    // Ambil warna latar belakang elemen dalam format RGB
    var warnaRGB = $elemen.css("background-color");

    // Ubah format RGB menjadi nilai numerik
    var warnaNumerik = warnaRGB.match(/\d+/g);

    // Hitung kecerahan elemen (rata-rata nilai RGB)
    var kecerahan =
      (parseInt(warnaNumerik[0]) +
        parseInt(warnaNumerik[1]) +
        parseInt(warnaNumerik[2])) /
      3;

    // Tentukan batas kecerahan yang dianggap terang (contoh: 200)
    var batasKecerahan = 200;

    // Jika elemen terang, ubah warna
    if (kecerahan > batasKecerahan) {
      $elemen.css("background-color", "#1c1c1c"); // Ganti dengan warna yang diinginkan
    }
  };

  const setTheme = (theme) => {
    const nav = document.querySelector("nav");
    console.log(theme);
    if (
      theme === "auto" ||
      (theme === "dark" &&
        window.matchMedia("(prefers-color-scheme: dark)").matches)
    ) {
      document.documentElement.setAttribute("data-bs-theme", "dark");
      if (nav) {
        nav.classList.add("bg-dark");
        nav.classList.remove("bg-white");
      }
      $(".btn-dark").addClass("btn-light").removeClass("btn-dark");
      $(".btn-outline-dark")
        .addClass("btn-outline-light")
        .removeClass("btn-outline-dark");
      $(".product").each(function () {
        ubahWarnaJikaTerang($(this));
      });
    } else {
      document.documentElement.setAttribute("data-bs-theme", theme);
      if (nav) {
        nav.classList.add("bg-white");
        nav.classList.remove("bg-dark");
      }
      $(".btn-light").addClass("btn-dark").removeClass("btn-light");
      $(".btn-outline-light")
        .addClass("btn-outline-dark")
        .removeClass("btn-outline-light");
      $(".product").each(function () {
        $(this).css("background-color", "#f2f2f2");
      });
    }
  };

  setTheme(getPreferredTheme());

  const showActiveTheme = (theme, focus = false) => {
    const themeSwitcher = document.querySelector("#bd-theme");

    if (!themeSwitcher) {
      return;
    }

    const themeSwitcherText = document.querySelector("#bd-theme-text");
    const activeThemeIcon = document.querySelector(".theme-icon-active use");
    const btnToActive = document.querySelector(
      `[data-bs-theme-value="${theme}"]`
    );
    const svgOfActiveBtn = btnToActive
      .querySelector("svg use")
      .getAttribute("href");

    document.querySelectorAll("[data-bs-theme-value]").forEach((element) => {
      element.classList.remove("active");
      element.setAttribute("aria-pressed", "false");
    });

    btnToActive.classList.add("active");
    btnToActive.setAttribute("aria-pressed", "true");
    activeThemeIcon.setAttribute("href", svgOfActiveBtn);
    const themeSwitcherLabel = `${themeSwitcherText.textContent} (${btnToActive.dataset.bsThemeValue})`;
    themeSwitcher.setAttribute("aria-label", themeSwitcherLabel);

    if (focus) {
      themeSwitcher.focus();
    }
  };

  window
    .matchMedia("(prefers-color-scheme: dark)")
    .addEventListener("change", () => {
      const storedTheme = getStoredTheme();
      if (storedTheme !== "light" && storedTheme !== "dark") {
        setTheme(getPreferredTheme());
      }
    });

  window.addEventListener("DOMContentLoaded", () => {
    showActiveTheme(getPreferredTheme());

    document.querySelectorAll("[data-bs-theme-value]").forEach((toggle) => {
      toggle.addEventListener("click", () => {
        const theme = toggle.getAttribute("data-bs-theme-value");
        setStoredTheme(theme);
        setTheme(theme);
        showActiveTheme(theme, true);
      });
    });
  });
})();
